(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16183,        551]*)
(*NotebookOutlinePosition[     16856,        574]*)
(*  CellTagsIndexPosition[     16812,        570]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["14. Vibrations in solids", "Title"],

Cell[BoxData[{
    \(<< Lautrup`\), "\n", 
    \(<< Graphics`PlotField`\), "\[IndentingNewLine]", 
    \(<< Graphics`PlotField3D`\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vector field plots", "Title"],

Cell[CellGroupData[{

Cell["Pressure wave", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell[BoxData[
    \(\(PlotVectorField[{0, Sin[2  y]}, {x, 0, \[Pi]}, {y, 0, \[Pi]}, 
          PlotPoints \[Rule] 13, ScaleFactor \[Rule] 0.2, 
          AspectRatio \[Rule] 1, HeadScaling \[Rule] Relative, 
          HeadLength \[Rule] 0.2, HeadWidth \[Rule] 1, 
          HeadCenter \[Rule] 
            0.3] // \[IndentingNewLine]Figure["\<vibrations0a\>"];\)\)], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Shear wave", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell[BoxData[
    \(\(PlotVectorField[{Sin[2\ y], 0}, {x, 0, \[Pi]}, {y, 0, \[Pi]}, 
          PlotPoints \[Rule] 13, ScaleFactor -> 0.2, AspectRatio \[Rule] 1, 
          HeadScaling \[Rule] Relative, HeadLength \[Rule] 0.2, 
          HeadWidth \[Rule] 1, 
          HeadCenter \[Rule] 
            0.3] // \[IndentingNewLine]Figure["\<vibrations0b\>"];\)\)], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rayleigh wave", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Rayleigh wave field", "Text"],

Cell[BoxData[{
    \(\(u\_x = \(-\[Kappa]\_T\)\ Sin[
              k\ x]\ \[ExponentialE]\^\(\(\[Kappa]\_T\) z\) + 
          k\ Cos[k\ x] \[ExponentialE]\^\(\(\[Kappa]\_L\) z\);\)\), "\
\[IndentingNewLine]", 
    \(\(u\_z = 
        k\ Sin[k\ x]\ \[ExponentialE]\^\(\(\[Kappa]\_T\) z\) + \[Kappa]\_L\ \
Cos[k\ x] \[ExponentialE]\^\(\(\[Kappa]\_L\) z\);\)\)}], "Input"],

Cell["Choice of parameters", "Text"],

Cell[BoxData[{
    \(\(k = 1;\)\), "\[IndentingNewLine]", 
    \(\(\[Kappa]\_T = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(\[Kappa]\_L = 0.7;\)\)}], "Input"],

Cell[BoxData[
    \(\(figa = 
        PlotVectorField[{u\_x, u\_z}, {x, 0, 2  \[Pi]}, {z, \(-\[Pi]\), 0}, 
          PlotPoints \[Rule] 15, ScaleFactor \[Rule] 0.35, 
          AspectRatio \[Rule] 1/2, HeadScaling \[Rule] Relative, 
          HeadLength \[Rule] 0.4, HeadWidth \[Rule] 1, 
          HeadCenter \[Rule] 0.2];\)\)], "Input"],

Cell[BoxData[
    \(\(figb = 
        ParametricPlot[{x + 0.3  u\_x, \ 0.3  u\_z} /. z \[Rule] 0, {x, 0, 
            2  \[Pi]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[figa, figb, 
          Graphics[{Dashing[{0.01}], 
              Line[{{0, 0}, {2  \[Pi], 
                    0}}]}]] // \[IndentingNewLine]Figure["\<vibrations4\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Supertransverse refraction", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Fresnel relation", "Text"],

Cell[BoxData[
    \(\(A = \(\[Mu]\ \ Cot[\[Theta]] - \[Mu]p\ \@\(\((c\/\(cp\ \
Sin[\[Theta]]\))\)\^2 - 1\)\)\/\(\[Mu]\ \ Cot[\[Theta]] + \[Mu]p\ \
\@\(\((c\/\(cp\ Sin[\[Theta]]\))\)\^2 - 1\)\);\)\)], "Input"],

Cell["Choice of parameters", "Text"],

Cell[BoxData[{
    \(\(c = 1;\)\), "\[IndentingNewLine]", 
    \(\(cp = 2;\)\), "\[IndentingNewLine]", 
    \(\(\[Mu] = \(\[Mu]p = 1\);\)\)}], "Input"],

Cell[BoxData[
    \(\[Theta]\_max = ArcSin[c\/cp]\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[{\[Theta]\/Degree, A}, {\[Theta], 0, \[Theta]\_max}, 
          AxesLabel \[Rule] {"\<\[Theta]\>", "\<A\>"}, 
          PlotLabel -> "\<(a)\>", 
          PlotRange \[Rule] {0, 
              1}] // \[IndentingNewLine]Figure["\<vibrations2a\>", 
          ImageSize \[Rule] 250];\)\)], "Input"],

Cell["Other example", "Text"],

Cell[BoxData[{
    \(\(c = 1;\)\), "\[IndentingNewLine]", 
    \(\(cp = 1\/2;\)\), "\[IndentingNewLine]", 
    \(\(\[Mu] = 1;\)\), "\[IndentingNewLine]", 
    \(\(\[Mu]p = 1;\)\)}], "Input"],

Cell[BoxData[
    \(\(\[Theta]\_max = \[Pi]\/2;\)\)], "Input"],

Cell[BoxData[
    \(\(\(ParametricPlot[{\[Theta]\/Degree, \(-A\)}, {\[Theta], 
              0, \[Theta]\_max}, 
            AxesLabel \[Rule] {"\<\[Theta]\>", "\<-A\>"}, 
            PlotLabel -> "\<(b)\>", 
            PlotRange \[Rule] {1, 
                0}] // \[IndentingNewLine]Figure["\<vibrations2b\>", 
            ImageSize \[Rule] 250];\);\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reflection at a free surface", "Title"],

Cell[CellGroupData[{

Cell["Transverse reflection", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Displacement field", "Text"],

Cell[BoxData[
    \(\(u = \(({\(-k\_T\), 0, 
                  k} \[ExponentialE]\^\(\[ImaginaryI]\ \(k\_T\) z\) + \
\(A\_L\) {k, 
                  0, \(-k\_L\)} \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \(k\_L\
\) z\) + \(A\_T\) {k\_T, 0, 
                  k} \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \(k\_T\) z\))\) \
\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\);\)\)], "Input"],

Cell[BoxData[{
    \(\(u\_x = u[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(\(u\_z = u[\([3]\)];\)\)}], "Input"],

Cell["Strains", "Text"],

Cell[BoxData[{
    \(\(u\_xx = \[PartialD]\_x u\_x;\)\), "\[IndentingNewLine]", 
    \(\(u\_zz = \[PartialD]\_z u\_z;\)\)}], "Input"],

Cell[BoxData[
    \(u\_xx + u\_zz // Simplify\)], "Input"],

Cell[BoxData[
    \(\(u\_xz = \(1\/2\) \((\[PartialD]\_x u\_z + \[PartialD]\_z \
u\_x)\);\)\)], "Input"],

Cell["Stresses", "Text"],

Cell[BoxData[
    \(\(\[Sigma]\_xz = \[Mu]\ u\_xz;\)\)], "Input"],

Cell[BoxData[
    \(zero1 = \[Sigma]\_xz\ \  /. {z \[Rule] 0, x \[Rule] 0} // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(\(\[Sigma]\_zz = 
        2  \[Mu]\ u\_zz + \[Lambda] \((u\_xx + u\_zz)\);\)\)], "Input"],

Cell[BoxData[
    \(zero2 = \(\[Sigma]\_zz /. {z \[Rule] 0, x \[Rule] 0} // Simplify\) // 
        Collect[#, {A, B}] &\)], "Input"],

Cell["Determine amplitudes", "Text"],

Cell[BoxData[
    \(zero2 = 
      zero2 /. \((\[Lambda] + 
                  2\ \[Mu])\)\ k\_L\%2 \[Rule] \[Mu] \((k\_T\^2 + 
                    k\^2)\) - \((\[Lambda] + 2\ \[Mu])\)\ k\^2 // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(sol = \(Solve[{zero1 \[Equal] 0, zero2 \[Equal] 0}, {A\_T, A\_L}] // 
          First\) // Simplify\)], "Input"],

Cell[BoxData[
    \({A\_T, A\_L} = {A\_T, A\_L} /. sol\)], "Input"],

Cell["Check solution", "Text"],

Cell[BoxData[
    \(zero1 // Simplify\)], "Input"],

Cell[BoxData[
    \(zero2 // Simplify\)], "Input"],

Cell["Simplify Fresnel relations", "Text"],

Cell[BoxData[
    \({A\_T, \ 
        A\_L} = {A\_T, \ A\_L} /. {k\_T \[Rule] k\ Cot[\[Theta]], 
            k\_L \[Rule] k\ Cot[\[Theta]']} // Simplify\)], "Input"],

Cell[BoxData[
    \({A\_T, \ A\_L} = {A\_T, \ A\_L} /. 
        Cot[\[Theta]'] -> \@\(q\^2\/Sin[\[Theta]]\^2 - 1\)\)], "Input"],

Cell[BoxData[
    \(\(q = 1\/2;\)\)], "Input"],

Cell[BoxData[
    \(\[Theta]\_max = ArcSin[q]\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[{{\[Theta]/\ Degree, A\_T}, \ {\[Theta]\ /Degree, 
              A\_L}}, {\[Theta], 0, \[Theta]\_max}, PlotLabel -> "\<(a)\>", 
          AxesLabel \[Rule] {"\<\[Theta]\>", "\<A\>"}, PlotRange \[Rule] All, 
          PlotStyle \[Rule] {Text["\<TL\>", {25, \(-1.7\)}, {1, 1}], 
              Text["\<TT\>", {25, \(-0.5\)}, {1, 
                  1}]}] // \[IndentingNewLine]Figure["\<vibrations1a\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compare with Landau and Lifshitz p. 91", "Section"],

Cell[BoxData[
    \(\(d = \(Sin[\[Theta]]\^2\) Sin[2  \[Theta]] 
            Sin[2  \[Theta]'] + \(Sin[\[Theta]']\^2\) 
            Cos[2  \[Theta]]\^2;\)\)], "Input"],

Cell[BoxData[
    \(\(\(d/Sin[\[Theta]]\^4\)/Sin[\[Theta]']\^2 // TrigExpand\) // 
      FullSimplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Longitudinal reflection", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Displacement field", "Text"],

Cell[BoxData[
    \(\(u = \(({k, 0, 
                  k\_L} \[ExponentialE]\^\(\[ImaginaryI]\ \(k\_L\) z\) + \
\(A\_L\) {k, 
                  0, \(-k\_L\)} \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \(k\_L\
\) z\) + \(A\_T\) {k\_T, 0, 
                  k} \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \(k\_T\) z\))\) \
\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\);\)\)], "Input"],

Cell[BoxData[{
    \(\(u\_x = u[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(\(u\_z = u[\([3]\)];\)\)}], "Input"],

Cell["Strains", "Text"],

Cell[BoxData[{
    \(\(u\_xx = \[PartialD]\_x u\_x;\)\), "\[IndentingNewLine]", 
    \(\(u\_zz = \[PartialD]\_z u\_z;\)\)}], "Input"],

Cell[BoxData[
    \(u\_xx + u\_zz // Simplify\)], "Input"],

Cell[BoxData[
    \(\(u\_xz = \(1\/2\) \((\[PartialD]\_x u\_z + \[PartialD]\_z \
u\_x)\);\)\)], "Input"],

Cell["Stresses", "Text"],

Cell[BoxData[
    \(\(\[Sigma]\_xz = \[Mu]\ u\_xz;\)\)], "Input"],

Cell[BoxData[
    \(zero1 = \[Sigma]\_xz\ \  /. {z \[Rule] 0, x \[Rule] 0} // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(\(\[Sigma]\_zz = 
        2  \[Mu]\ u\_zz + \[Lambda] \((u\_xx + u\_zz)\);\)\)], "Input"],

Cell[BoxData[
    \(zero2 = \(\[Sigma]\_zz /. {z \[Rule] 0, x \[Rule] 0} // Simplify\) // 
        Collect[#, {A, B}] &\)], "Input"],

Cell["Solve for amplitudes", "Text"],

Cell[BoxData[
    \(zero2 = 
      zero2 /. \((\[Lambda] + 
                  2\ \[Mu])\)\ k\_L\%2 \[Rule] \[Mu] \((k\_T\^2 + 
                    k\^2)\) - \((\[Lambda] + 2\ \[Mu])\)\ k\^2 // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(sol = \(Solve[{zero1 \[Equal] 0, zero2 \[Equal] 0}, {A\_T, A\_L}] // 
          First\) // Simplify\)], "Input"],

Cell[BoxData[
    \({A\_T, A\_L} = {A\_T, A\_L} /. sol\)], "Input"],

Cell["Check solution", "Text"],

Cell[BoxData[
    \(zero1 // Simplify\)], "Input"],

Cell[BoxData[
    \(zero2 // Simplify\)], "Input"],

Cell["Simplify solution", "Text"],

Cell[BoxData[
    \({A\_T, \ 
        A\_L} = {A\_T, \ A\_L} /. {k\_L \[Rule] k\ Cot[\[Theta]], 
            k\_T \[Rule] k\ Cot[\[Theta]']} // Simplify\)], "Input"],

Cell[BoxData[
    \(\({A\_T, \ A\_L} = {A\_T, \ A\_L} /. 
          Cot[\[Theta]'] -> \@\(1\/\(\(q\^2\) Sin[\[Theta]]\^2\) - 1\);\)\)], \
"Input"],

Cell["Choice of parameter", "Text"],

Cell[BoxData[
    \(\(q = 1\/2;\)\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[{{\[Theta]/\ Degree, A\_T}, \ {\[Theta]\ /Degree, 
              A\_L}}, {\[Theta], 0, \[Pi]\/2}, PlotLabel -> "\<(b)\>", 
          AxesLabel \[Rule] {"\<\[Theta]\>", "\<A\>"}, PlotRange \[Rule] All, 
          PlotStyle \[Rule] {Text["\<LL\>", {70, \(-0.35\)}, {1, \(-1\)}], 
              Text["\<LT\>", {70, 
                  0.45}, {1, \(-1\)}]}] \
// \[IndentingNewLine]Figure["\<vibrations1b\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rayleigh waves", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[TextData[{
  "Equation for ",
  StyleBox["c/c_T", "Input"],
  " in terms of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x = \[Xi]\^2\),
          "Input"], TraditionalForm]], "InlineFormula"]
}], "Text"],

Cell[BoxData[{
    \(\(zero = \((2 - x)\)\^4 - 
          16 \((1 - x)\) \((1 - \(q\^2\) x)\);\)\), "\[IndentingNewLine]", 
    \(\(zero/x // Expand\) // Collect[#, q] &\)}], "Input"],

Cell["Expand near x=1", "Text"],

Cell[BoxData[
    \(\(16 - 24  x + 8  x\^2 - x\^3\)\/\(16 \((1 - x)\)\) /. x \[Rule] 1 - y // 
      Expand\)], "Input"],

Cell["Find  max value of \[Xi]", "Text"],

Cell[BoxData[
    \(\(q = \@\(\(16 - 24  \[Xi]\^2 + 8  \[Xi]\^4 - \[Xi]\^6\)\/\(16 \((1 - \
\[Xi]\^2)\)\)\);\)\)], "Input"],

Cell[BoxData[
    \(Solve[
      16 - 24  \[Xi]\^2 + 8  \[Xi]\^4 - \[Xi]\^6 \[Equal] 
        0, \[Xi]]\)], "Input"],

Cell[BoxData[
    \(\[Xi]\_0 = \@\(8\/3 - 4\/\(3\ \((\(-17\) + 3\ \@33)\)\^\(1/3\)\) + 2\/3\
\ \((\(-17\) + 3\ \@33)\)\^\(1/3\)\) // N\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[{q, \[Xi]}, {\[Xi], 0, \[Xi]\_0}, 
          AxesLabel \[Rule] {\*"\"\<\!\(c\_T\/c\_L\)\>\"", \*"\"\<\!\(c\/c\_T\
\)\>\""}, 
          PlotLabel -> "\<(a)\>"] \
// \[IndentingNewLine]Figure["\<vibrations3a\>", 
          ImageSize \[Rule] 250];\)\)], "Input"],

Cell["Solve generally for \[Xi]", "Text"],

Cell[BoxData[
    \(f[qq_] := \[Xi] /. 
        FindRoot[q \[Equal] qq, {\[Xi], \[Xi]\_0}]\)], "Input"],

Cell[BoxData[
    \(f[0.5]\)], "Input"],

Cell["Compare with approximation", "Text"],

Cell[BoxData[
    \(\(g[qq_] = 1 - 1\/\(2 \((11 - 16  qq\^2)\)\);\)\)], "Input"],

Cell[BoxData[
    \(g[0.5] // N\)], "Input"],

Cell[BoxData[
    \(f[0.7]\)], "Input"],

Cell[BoxData[
    \(g[0.7]\)], "Input"],

Cell["Amplitude ratio", "Text"],

Cell[BoxData[
    \(\(R = \(2 \@\( 1 - \[Xi]\^2\)\)\/\(2 - \[Xi]\^2\);\)\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[{q, R}, {\[Xi], 0, \[Xi]\_0}, 
          AxesLabel \[Rule] {\*"\"\<\!\(c\_T\/c\_L\)\>\"", \*"\"\<\!\(\(\
\[ImaginaryI]\\\ A\_L\)\/A\_T\)\>\""}, PlotRange \[Rule] {0, 1}, 
          PlotLabel -> "\<(b)\>"] \
// \[IndentingNewLine]Figure["\<vibrations3b\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Love Waves", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\(f[\[Xi]_, 
          n_] = \(\[Xi]\/\@\(\[Xi]\^2 - 1\)\) \((ArcTan[\(\[Mu]\/\[Mu]p\) \
\@\(\(1 - \(q\^2\) \[Xi]\^2\)\/\(\[Xi]\^2 - 1\)\)] + 
              n\ \[Pi])\);\)\)], "Input"],

Cell[BoxData[{
    \(\(q = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(\[Mu] = \(\[Mu]p = 1\);\)\)}], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[
          Table[{f[\[Xi], n], \[Xi]}, {n, 0, 8}] // Evaluate, {\[Xi], 1, 
            1\/q}, PlotRange \[Rule] {{0, 30}, All}, 
          PlotLabel \[Rule] "\<(a)\>", 
          AxesLabel \[Rule] {\*"\"\<\!\(\(\[Omega]\\\ h\)\/c\_T'\)\>\"", \
\*"\"\<\!\(c\/c\_T'\)\>\""}] // \[IndentingNewLine]Figure["\<vibrations5a\>", 
          ImageSize \[Rule] 250];\)\)], "Input"],

Cell[BoxData[
    \(\(g[\[Xi]_] = \((1 + \(\[Mu]\/\[Mu]p\) \@\(\(1 - \(q\^2\) \
\[Xi]\^2\)\/\(\[Xi]\^2 - 1\)\))\)\^\(\(-1\)/2\);\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[g[\[Xi]], {\[Xi], 1, 1\/q}, PlotLabel -> "\<(b)\>", 
          AxesLabel \[Rule] {\*"\"\<\!\(c\/c\_T'\)\>\"", \*"\"\<\!\(A\/A'\)\>\
\""}] // \[IndentingNewLine]Figure["\<vibrations5b\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
AutoGeneratedPackage->None,
WindowSize->{749, 834},
WindowMargins->{{106, Automatic}, {8, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 41, 0, 95, "Title"],
Cell[1820, 55, 171, 4, 70, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[2028, 64, 35, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[2088, 68, 32, 0, 73, "Section"],
Cell[2123, 70, 51, 1, 30, "Input"],
Cell[2177, 73, 377, 7, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2591, 85, 29, 0, 73, "Section"],
Cell[2623, 87, 51, 1, 30, "Input"],
Cell[2677, 90, 372, 7, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3086, 102, 32, 0, 73, "Section"],
Cell[3121, 104, 46, 1, 30, "Input"],
Cell[3170, 107, 35, 0, 33, "Text"],
Cell[3208, 109, 369, 7, 50, "Input"],
Cell[3580, 118, 36, 0, 33, "Text"],
Cell[3619, 120, 157, 3, 70, "Input"],
Cell[3779, 125, 338, 6, 70, "Input"],
Cell[4120, 133, 144, 3, 30, "Input"],
Cell[4267, 138, 243, 5, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4559, 149, 43, 0, 95, "Title"],
Cell[4605, 151, 46, 1, 30, "Input"],
Cell[4654, 154, 32, 0, 33, "Text"],
Cell[4689, 156, 208, 3, 93, "Input"],
Cell[4900, 161, 36, 0, 33, "Text"],
Cell[4939, 163, 151, 3, 70, "Input"],
Cell[5093, 168, 62, 1, 42, "Input"],
Cell[5158, 171, 331, 6, 86, "Input"],
Cell[5492, 179, 29, 0, 33, "Text"],
Cell[5524, 181, 190, 4, 104, "Input"],
Cell[5717, 187, 62, 1, 40, "Input"],
Cell[5782, 190, 367, 7, 86, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6186, 202, 45, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[6256, 206, 40, 0, 73, "Section"],
Cell[6299, 208, 46, 1, 30, "Input"],
Cell[6348, 211, 34, 0, 33, "Text"],
Cell[6385, 213, 373, 7, 32, "Input"],
Cell[6761, 222, 113, 2, 50, "Input"],
Cell[6877, 226, 23, 0, 33, "Text"],
Cell[6903, 228, 133, 2, 50, "Input"],
Cell[7039, 232, 58, 1, 30, "Input"],
Cell[7100, 235, 104, 2, 42, "Input"],
Cell[7207, 239, 24, 0, 33, "Text"],
Cell[7234, 241, 65, 1, 30, "Input"],
Cell[7302, 244, 108, 2, 30, "Input"],
Cell[7413, 248, 109, 2, 30, "Input"],
Cell[7525, 252, 132, 2, 30, "Input"],
Cell[7660, 256, 36, 0, 33, "Text"],
Cell[7699, 258, 223, 5, 31, "Input"],
Cell[7925, 265, 132, 2, 30, "Input"],
Cell[8060, 269, 67, 1, 30, "Input"],
Cell[8130, 272, 30, 0, 33, "Text"],
Cell[8163, 274, 50, 1, 30, "Input"],
Cell[8216, 277, 50, 1, 30, "Input"],
Cell[8269, 280, 42, 0, 33, "Text"],
Cell[8314, 282, 165, 3, 30, "Input"],
Cell[8482, 287, 127, 2, 50, "Input"],
Cell[8612, 291, 46, 1, 42, "Input"],
Cell[8661, 294, 58, 1, 30, "Input"],
Cell[8722, 297, 486, 7, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9245, 309, 57, 0, 73, "Section"],
Cell[9305, 311, 167, 3, 30, "Input"],
Cell[9475, 316, 114, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9626, 323, 42, 0, 73, "Section"],
Cell[9671, 325, 46, 1, 30, "Input"],
Cell[9720, 328, 34, 0, 33, "Text"],
Cell[9757, 330, 368, 7, 32, "Input"],
Cell[10128, 339, 113, 2, 50, "Input"],
Cell[10244, 343, 23, 0, 33, "Text"],
Cell[10270, 345, 133, 2, 50, "Input"],
Cell[10406, 349, 58, 1, 30, "Input"],
Cell[10467, 352, 104, 2, 42, "Input"],
Cell[10574, 356, 24, 0, 33, "Text"],
Cell[10601, 358, 65, 1, 30, "Input"],
Cell[10669, 361, 108, 2, 30, "Input"],
Cell[10780, 365, 109, 2, 30, "Input"],
Cell[10892, 369, 132, 2, 30, "Input"],
Cell[11027, 373, 36, 0, 33, "Text"],
Cell[11066, 375, 223, 5, 31, "Input"],
Cell[11292, 382, 132, 2, 30, "Input"],
Cell[11427, 386, 67, 1, 30, "Input"],
Cell[11497, 389, 30, 0, 33, "Text"],
Cell[11530, 391, 50, 1, 30, "Input"],
Cell[11583, 394, 50, 1, 30, "Input"],
Cell[11636, 397, 33, 0, 33, "Text"],
Cell[11672, 399, 165, 3, 30, "Input"],
Cell[11840, 404, 146, 3, 51, "Input"],
Cell[11989, 409, 35, 0, 33, "Text"],
Cell[12027, 411, 46, 1, 42, "Input"],
Cell[12076, 414, 490, 8, 102, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12615, 428, 31, 0, 95, "Title"],
Cell[12649, 430, 46, 1, 30, "Input"],
Cell[12698, 433, 217, 8, 34, "Text"],
Cell[12918, 443, 183, 3, 51, "Input"],
Cell[13104, 448, 31, 0, 33, "Text"],
Cell[13138, 450, 120, 2, 47, "Input"],
Cell[13261, 454, 40, 0, 33, "Text"],
Cell[13304, 456, 123, 2, 50, "Input"],
Cell[13430, 460, 116, 3, 31, "Input"],
Cell[13549, 465, 147, 2, 63, "Input"],
Cell[13699, 469, 296, 6, 63, "Input"],
Cell[13998, 477, 41, 0, 33, "Text"],
Cell[14042, 479, 103, 2, 30, "Input"],
Cell[14148, 483, 39, 1, 30, "Input"],
Cell[14190, 486, 42, 0, 33, "Text"],
Cell[14235, 488, 80, 1, 44, "Input"],
Cell[14318, 491, 44, 1, 30, "Input"],
Cell[14365, 494, 39, 1, 30, "Input"],
Cell[14407, 497, 39, 1, 30, "Input"],
Cell[14449, 500, 31, 0, 33, "Text"],
Cell[14483, 502, 85, 1, 50, "Input"],
Cell[14571, 505, 342, 6, 87, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14950, 516, 27, 0, 95, "Title"],
Cell[14980, 518, 46, 1, 30, "Input"],
Cell[15029, 521, 204, 4, 55, "Input"],
Cell[15236, 527, 108, 2, 50, "Input"],
Cell[15347, 531, 408, 7, 101, "Input"],
Cell[15758, 540, 143, 2, 54, "Input"],
Cell[15904, 544, 263, 4, 65, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

