(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13000,        494]*)
(*NotebookOutlinePosition[     13672,        517]*)
(*  CellTagsIndexPosition[     13628,        513]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["17. Viscosity", "Title",
  InitializationCell->True],

Cell[BoxData[
    \(<< Lautrup`\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Momentum diffusion", "Title"],

Cell[CellGroupData[{

Cell["Gaussian river", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Check that the following satisfies the diffusion equation", "Text"],

Cell[BoxData[
    \(\(v\_x = \(v\_0\) \(a\/\@\(a\^2 + 4  \[Nu]\ t\)\) 
          Exp[\(-\(y\^2\/\(a\^2 + 4  \[Nu]\ t\)\)\)];\)\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_t v\_x - \[Nu]\ \[PartialD]\_y\(\[PartialD]\_y v\_x\) // 
      Simplify\)], "Input"],

Cell["Plot Gaussians of different widths", "Text"],

Cell[BoxData[
    \(\(Plot[{\@5\ Exp[\(-5\) y\^2], 
            Exp[\(-y\^2\)], \(1\/\@5\) Exp[\(-y\^2\)\/5]}, {y, \(-3\), 3}, 
          PlotRange \[Rule] All, Ticks \[Rule] None, 
          AxesLabel \[Rule] {"\<y\>", \*"\"\<\!\(v\_x\)\>\""}] \
// \[IndentingNewLine]Figure["\<viscosity2\>", 
          ImageSize \[Rule] 200];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transverse waves", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["\<\
Show that the following exprssion satisfies the diffusion equation\
\>", "Text"],

Cell[BoxData[{
    \(\(k = \@\(\[Omega]\/\(2  \[Nu]\)\);\)\), "\n", 
    \(\(v\_x = \(U\_0\) \(\[ExponentialE]\^\(\(-k\)\ y\)\) 
          Cos[k\ y - \[Omega]\ t];\)\)}], "Input"],

Cell[BoxData[
    \(\[PartialD]\_t v\_x - \[Nu]\ \[PartialD]\_y\(\[PartialD]\_y v\_x\) // 
      Simplify\)], "Input"],

Cell[BoxData[
    \(\(Plot[Exp[\(-2\) \[Pi]\ y] Cos[2  \[Pi]\ y], {y, 0, 0.7}, 
          PlotRange -> {\(-0.25\), 1}, 
          AxesLabel -> {"\<y\>", \*"\"\<\!\(v\_x\)\>\""}, 
          Ticks \[Rule] None] // \[IndentingNewLine]Figure["\<viscosity3\>", 
          ImageSize \[Rule] 200];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Attenuation of sound", "Title"],

Cell[CellGroupData[{

Cell["Damped wave", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Density variation", "Text"],

Cell[BoxData[
    \(\(\[CapitalDelta]\[Rho] = \(\[ExponentialE]\^\(\(-\[Kappa]\)\ x\)\) 
          Cos[k\ x - \[Omega]\ t];\)\)], "Input"],

Cell["Equation of motion", "Text"],

Cell[BoxData[
    \(\(zero = \[PartialD]\_t\(\[PartialD]\_t \[CapitalDelta]\[Rho]\) - \
\(c\_0\^2\) \[PartialD]\_x\(\[PartialD]\_x \[CapitalDelta]\[Rho]\) - 
          q\ \[PartialD]\_x\(\[PartialD]\_x\(\[PartialD]\_t \[CapitalDelta]\
\[Rho]\)\);\)\)], "Input"],

Cell["Simplify result", "Text"],

Cell[BoxData[
    \(zero1 = \(zero\ \[ExponentialE]\^\(\[Kappa]\ x\) // Expand\) // 
        Collect[#, \ {Cos[k\ x - t\ \[Omega]], 
              Sin[k\ x - tx\ \[Omega]]}] &\)], "Input"],

Cell["Kill second order terms", "Text"],

Cell[BoxData[
    \(zero1 /. {\[Kappa]\^2 \[Rule] 0, \[Omega]\ q\ \[Kappa] \[Rule] 0} // 
      Expand\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Air", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Parameters for air", "Text"],

Cell[BoxData[{
    \(\(\[Eta] = 
        1.8\ 10\^\(-5\)\ Pascal\ Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Zeta] = \[Eta];\)\), "\[IndentingNewLine]", 
    \(\(c\_0 = 343\ Meter/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_0 = 1.2\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = 1000\ /Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Omega] = 2  \[Pi]\ \[Nu];\)\)}], "Input"],

Cell["Base frequency", "Text"],

Cell[BoxData[
    \(\[Omega]\_0 = \(\(c\_0\^2\) \[Rho]\_0\)\/\(\[Zeta] + \(4\/3\) \[Eta]\) // 
        ToSI\)], "Input"],

Cell["Decay parameter", "Text"],

Cell[BoxData[
    \(\[Kappa] = \[Omega]\^2\/\(2 \( \[Omega]\_0\) c\_0\)\)], "Input"],

Cell["Attenuation length", "Text"],

Cell[BoxData[
    \(a = 1\/\[Kappa]\)], "Input"],

Cell["Wave length", "Text"],

Cell[BoxData[
    \(\[Lambda] = c\_0\/\[Nu] // N\)], "Input"],

Cell["Number of wavelengths to attenuate", "Text"],

Cell[BoxData[
    \(a\/\[Lambda]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Water", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Parameters for water", "Text"],

Cell[BoxData[{
    \(\(\[Eta] = \ 
        1.0\ 10\^\(-3\)\ Pascal\ Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Zeta] = \[Eta];\)\), "\[IndentingNewLine]", 
    \(\(c\_0 = 1500\ Meter/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_0 = 1000\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = 1000\ /Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Omega] = 2  \[Pi]\ \[Nu] // N;\)\)}], "Input"],

Cell["Base frequency", "Text"],

Cell[BoxData[
    \(\[Omega]\_0 = \(\(c\_0\^2\) \[Rho]\_0\)\/\(\[Zeta] + \(4\/3\) \[Eta]\) // 
        ToSI\)], "Input"],

Cell["Decay parameter", "Text"],

Cell[BoxData[
    \(\[Kappa] = \[Omega]\^2\/\(2 \( \[Omega]\_0\) c\_0\)\)], "Input"],

Cell["Attenuation length", "Text"],

Cell[BoxData[
    \(a = 1\/\[Kappa]\)], "Input"],

Cell["Wave length", "Text"],

Cell[BoxData[
    \(\[Lambda] = c\_0\/\[Nu] // N\)], "Input"],

Cell["Number of wavelengths to attenuate", "Text"],

Cell[BoxData[
    \(a\/\[Lambda]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Longitudinal wave amplitude", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[Exp[\(-0.5\)\ y] Cos[\ 2\ Pi\ y], {y, 0, 5}, 
          PlotRange -> {\(-1\), 1}, AxesLabel -> {"\<x\>", "\<\[Rho]\>"}, 
          Ticks \[Rule] None] // \[IndentingNewLine]Figure["\<viscosity4\>", 
          ImageSize \[Rule] 200];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Title"],

Cell[CellGroupData[{

Cell["17.1.1 Air viscosity", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(\[Rho] = 1.2\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(\[Lambda] = 100.0\ Nanometer;\)\), "\[IndentingNewLine]", 
    \(\(M\_mol = AirMolarMass;\)\), "\[IndentingNewLine]", 
    \(\(R = MolarGasConstant;\)\), "\[IndentingNewLine]", 
    \(\(T = 293\ Kelvin;\)\)}], "Input"],

Cell["Molecular velocity", "Text"],

Cell[BoxData[
    \(v\_mol = \@\(3\ \(R\ T\)\/M\_mol\) // ToSI\)], "Input"],

Cell["Time between colissions", "Text"],

Cell[BoxData[
    \(\[Tau] = \[Lambda]\/v\_mol // ToUnit[Nanosecond]\)], "Input"],

Cell["Viscosity estimate", "Text"],

Cell[BoxData[
    \(\[Eta] = \[Rho]\ \[Lambda]\^2\/\(4  \[Tau]\) // 
        ToUnit[Pascal]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["17.2.1 Curling", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(U\_0 = 3\ Meter/Second;\)\), "\[IndentingNewLine]", 
    \(\(M = 20\ Kilogram;\)\), "\[IndentingNewLine]", 
    \(\(A = 700\ Centimeter\^2;\)\), "\[IndentingNewLine]", 
    \(\(L = 40\ Meter;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho] = \(10\^3\) Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(\[Eta] = 8.9\ \(10\^\(-4\)\) Pascal\ Second;\)\)}], "Input"],

Cell["Thickness", "Text"],

Cell[BoxData[
    \(d = \ \(L\ \[Eta]\ A\)\/\(\(U\_0\) \(M\)\(\ \)\) // 
        ToUnit[Micrometer]\)], "Input"],

Cell["Time scale for stopping", "Text"],

Cell[BoxData[
    \(t\_0 = \(L\/U\_0 // ToSI\) // N\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds = \(\[Rho]\ \(U\_0\) d\)\/\[Eta] // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["17.2.2 Shear sound", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Parameters for air", "Text"],

Cell[BoxData[{
    \(\(\[Nu] = 
        1.57\ \(10\^\(-5\)\) Meter\^2/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Omega] = 2\ \[Pi]\ 1000\ /Second;\)\)}], "Input"],

Cell["Wave number and wavelength", "Text"],

Cell[BoxData[{
    \(\(k = \@\(\[Omega]\/\(2  \[Nu]\)\);\)\), "\n", 
    \(\[Lambda] = \(2\ \[Pi]\)\/k // ToUnit[Millimeter]\)}], "Input"],

Cell["Transverse speed of sound", "Text"],

Cell[BoxData[
    \(C\_T = \[Omega]\/k // ToSI\)], "Input"],

Cell["Parameters for water", "Text"],

Cell[BoxData[
    \(\(\[Nu] = 1.0\ \(10\^\(-6\)\) Meter\^2/Second;\)\)], "Input"],

Cell[BoxData[{
    \(\(k = \@\(\[Omega]\/\(2  \[Nu]\)\);\)\), "\n", 
    \(\[Lambda] = \(2\ \[Pi]\)\/k // ToUnit[Millimeter]\)}], "Input"],

Cell[BoxData[
    \(C\_T = \[Omega]\/k // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["17.4.3 Water pipe", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Parameters for water", "Text"],

Cell[BoxData[{
    \(\(\[Nu] = \ \(10\^\(-6\)\) Meter\^2/Second;\)\), "\n", 
    \(\(d = 1.25\ Centimeter;\)\), "\n", 
    \(\(A = \(\[Pi]\ d\^2\)\/4;\)\), "\n", 
    \(\(Q = 0.1\ Liter/Second;\)\)}], "Input"],

Cell["Average velocity", "Text"],

Cell[BoxData[
    \(U = \(Q\/A // ToSI\) // N\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds\  = \ \(U\ d\)\/\[Nu] // ToSI\)], "Input"],

Cell["Parameters for oil pipe", "Text"],

Cell[BoxData[
    \(\(\[Nu] = 6.7\ \ \(10\^\(-2\)\) Meter\^2/Second;\)\)], "Input"],

Cell[BoxData[
    \(U = \(Q\/A // ToSI\) // N\)], "Input"],

Cell[BoxData[
    \(Reynolds\  = \ \(U\ d\)\/\[Nu] // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["17.4.4 Fly and Robofly", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Parameters for a fly wing", "Text"],

Cell[BoxData[{
    \(\(\[Nu] = 1.54\ \(10\^\(-5\)\) Meter\^2/Second;\)\), "\n", 
    \(\(L = 4\ Milli\ Meter;\)\), "\n", 
    \(\(f = 50\ Hertz;\)\)}], "Input"],

Cell["Average velocity estimated", "Text"],

Cell[BoxData[
    \(U = \(\[Pi]\ L\ f // ToSI\) // N\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds\  = \ \(U\ L\)\/\[Nu] // ToSI\)], "Input"],

Cell["Parameters for Robofly wing", "Text"],

Cell[BoxData[{
    \(\(\[Nu] = 1.15\ \ Centimeter\^2/Second;\)\), "\n", 
    \(\(L = 19\ Centimeter;\)\), "\n", 
    \(\(f = 168\ Milli\ Hertz;\)\)}], "Input"],

Cell[BoxData[
    \(\(1/f // ToSI\) // N\)], "Input"],

Cell[BoxData[
    \(U = \(\[Pi]\ L\ f // ToSI\) // N\)], "Input"],

Cell[BoxData[
    \(Reynolds\  = \ \(U\ L\)\/\[Nu] // ToSI\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Title"],

Cell[CellGroupData[{

Cell["17.2 Car braking on ice", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(U\_0 = 100\ Kilometer/Hour;\)\), "\[IndentingNewLine]", 
    \(\(M = 1000\ Kilogram;\)\), "\[IndentingNewLine]", 
    \(\(A = 4*800\ Centimeter\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho] = \(10\^3\) Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(\[Eta] = 
        8.9\ \(10\^\(-4\)\) Pascal\ Second;\)\), "\[IndentingNewLine]", 
    \(\(L = 300\ Meter;\)\)}], "Input"],

Cell["Thickness", "Text"],

Cell[BoxData[
    \(d = \ \(L\ \[Eta]\ A\)\/\(\(U\_0\) \(M\)\(\ \)\) // 
        ToUnit[Micrometer]\)], "Input"],

Cell["Time scale for stopping", "Text"],

Cell[BoxData[
    \(t\_0 = \(L\/U\_0 // ToSI\) // N\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds = \(\[Rho]\ \(U\_0\) d\)\/\[Eta] // ToSI\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 937}},
AutoGeneratedPackage->None,
WindowSize->{951, 903},
WindowMargins->{{86, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 58, 1, 95, "Title",
  InitializationCell->True],
Cell[1837, 56, 72, 2, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[1946, 63, 35, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[2006, 67, 33, 0, 73, "Section"],
Cell[2042, 69, 51, 1, 30, "Input"],
Cell[2096, 72, 73, 0, 33, "Text"],
Cell[2172, 74, 139, 2, 51, "Input"],
Cell[2314, 78, 118, 2, 30, "Input"],
Cell[2435, 82, 50, 0, 33, "Text"],
Cell[2488, 84, 343, 6, 74, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2868, 95, 35, 0, 73, "Section"],
Cell[2906, 97, 51, 1, 30, "Input"],
Cell[2960, 100, 90, 2, 33, "Text"],
Cell[3053, 104, 179, 3, 73, "Input"],
Cell[3235, 109, 118, 2, 30, "Input"],
Cell[3356, 113, 305, 5, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3710, 124, 37, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[3772, 128, 30, 0, 73, "Section"],
Cell[3805, 130, 51, 1, 30, "Input"],
Cell[3859, 133, 33, 0, 33, "Text"],
Cell[3895, 135, 138, 2, 30, "Input"],
Cell[4036, 139, 34, 0, 33, "Text"],
Cell[4073, 141, 261, 4, 30, "Input"],
Cell[4337, 147, 31, 0, 33, "Text"],
Cell[4371, 149, 188, 3, 30, "Input"],
Cell[4562, 154, 39, 0, 33, "Text"],
Cell[4604, 156, 115, 2, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4756, 163, 22, 0, 73, "Section"],
Cell[4781, 165, 51, 1, 30, "Input"],
Cell[4835, 168, 34, 0, 33, "Text"],
Cell[4872, 170, 405, 7, 130, "Input"],
Cell[5280, 179, 30, 0, 33, "Text"],
Cell[5313, 181, 120, 2, 54, "Input"],
Cell[5436, 185, 31, 0, 33, "Text"],
Cell[5470, 187, 84, 1, 47, "Input"],
Cell[5557, 190, 34, 0, 33, "Text"],
Cell[5594, 192, 48, 1, 42, "Input"],
Cell[5645, 195, 27, 0, 33, "Text"],
Cell[5675, 197, 61, 1, 40, "Input"],
Cell[5739, 200, 50, 0, 33, "Text"],
Cell[5792, 202, 45, 1, 40, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5874, 208, 24, 0, 73, "Section"],
Cell[5901, 210, 51, 1, 30, "Input"],
Cell[5955, 213, 36, 0, 33, "Text"],
Cell[5994, 215, 414, 7, 130, "Input"],
Cell[6411, 224, 30, 0, 33, "Text"],
Cell[6444, 226, 120, 2, 54, "Input"],
Cell[6567, 230, 31, 0, 33, "Text"],
Cell[6601, 232, 84, 1, 47, "Input"],
Cell[6688, 235, 34, 0, 33, "Text"],
Cell[6725, 237, 48, 1, 42, "Input"],
Cell[6776, 240, 27, 0, 33, "Text"],
Cell[6806, 242, 61, 1, 40, "Input"],
Cell[6870, 245, 50, 0, 33, "Text"],
Cell[6923, 247, 45, 1, 40, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7005, 253, 46, 0, 73, "Section"],
Cell[7054, 255, 51, 1, 30, "Input"],
Cell[7108, 258, 274, 4, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7431, 268, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[7481, 272, 39, 0, 73, "Section"],
Cell[7523, 274, 46, 1, 30, "Input"],
Cell[7572, 277, 26, 0, 33, "Text"],
Cell[7601, 279, 311, 5, 110, "Input"],
Cell[7915, 286, 34, 0, 33, "Text"],
Cell[7952, 288, 75, 1, 51, "Input"],
Cell[8030, 291, 39, 0, 33, "Text"],
Cell[8072, 293, 81, 1, 44, "Input"],
Cell[8156, 296, 34, 0, 33, "Text"],
Cell[8193, 298, 104, 2, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8334, 305, 33, 0, 73, "Section"],
Cell[8370, 307, 46, 1, 30, "Input"],
Cell[8419, 310, 26, 0, 33, "Text"],
Cell[8448, 312, 387, 6, 130, "Input"],
Cell[8838, 320, 25, 0, 33, "Text"],
Cell[8866, 322, 112, 2, 44, "Input"],
Cell[8981, 326, 39, 0, 33, "Text"],
Cell[9023, 328, 64, 1, 44, "Input"],
Cell[9090, 331, 31, 0, 33, "Text"],
Cell[9124, 333, 82, 1, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9243, 339, 37, 0, 73, "Section"],
Cell[9283, 341, 51, 1, 30, "Input"],
Cell[9337, 344, 34, 0, 33, "Text"],
Cell[9374, 346, 166, 3, 50, "Input"],
Cell[9543, 351, 42, 0, 33, "Text"],
Cell[9588, 353, 138, 2, 86, "Input"],
Cell[9729, 357, 41, 0, 33, "Text"],
Cell[9773, 359, 59, 1, 40, "Input"],
Cell[9835, 362, 36, 0, 33, "Text"],
Cell[9874, 364, 81, 1, 30, "Input"],
Cell[9958, 367, 138, 2, 86, "Input"],
Cell[10099, 371, 59, 1, 40, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10195, 377, 36, 0, 73, "Section"],
Cell[10234, 379, 51, 1, 30, "Input"],
Cell[10288, 382, 36, 0, 33, "Text"],
Cell[10327, 384, 209, 4, 107, "Input"],
Cell[10539, 390, 32, 0, 33, "Text"],
Cell[10574, 392, 58, 1, 42, "Input"],
Cell[10635, 395, 31, 0, 33, "Text"],
Cell[10669, 397, 71, 1, 42, "Input"],
Cell[10743, 400, 39, 0, 33, "Text"],
Cell[10785, 402, 83, 1, 30, "Input"],
Cell[10871, 405, 58, 1, 42, "Input"],
Cell[10932, 408, 71, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11040, 414, 41, 0, 73, "Section"],
Cell[11084, 416, 51, 1, 30, "Input"],
Cell[11138, 419, 41, 0, 33, "Text"],
Cell[11182, 421, 160, 3, 70, "Input"],
Cell[11345, 426, 42, 0, 33, "Text"],
Cell[11390, 428, 65, 1, 30, "Input"],
Cell[11458, 431, 31, 0, 33, "Text"],
Cell[11492, 433, 71, 1, 42, "Input"],
Cell[11566, 436, 43, 0, 33, "Text"],
Cell[11612, 438, 159, 3, 70, "Input"],
Cell[11774, 443, 53, 1, 30, "Input"],
Cell[11830, 446, 65, 1, 30, "Input"],
Cell[11898, 449, 71, 1, 42, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12018, 456, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[12068, 460, 42, 0, 73, "Section"],
Cell[12113, 462, 51, 1, 30, "Input"],
Cell[12167, 465, 26, 0, 33, "Text"],
Cell[12196, 467, 405, 7, 130, "Input"],
Cell[12604, 476, 25, 0, 33, "Text"],
Cell[12632, 478, 112, 2, 44, "Input"],
Cell[12747, 482, 39, 0, 33, "Text"],
Cell[12789, 484, 64, 1, 44, "Input"],
Cell[12856, 487, 31, 0, 33, "Text"],
Cell[12890, 489, 82, 1, 44, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

