(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16162,        640]*)
(*NotebookOutlinePosition[     16835,        663]*)
(*  CellTagsIndexPosition[     16791,        659]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["18. Channels and pipes", "Title",
  InitializationCell->True],

Cell[BoxData[{
    \(<< Lautrup`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics`\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Open surface flow", "Title"],

Cell[CellGroupData[{

Cell["Stability criterion", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Velocity field", "Text"],

Cell[BoxData[
    \(\(v\_x = \(3\/2\) U\ \(y\/h\) \((2 - y\/h)\);\)\)], "Input"],

Cell["Energy", "Text"],

Cell[BoxData[
    \(energy = 
      L\ W \(\[Integral]\_0\%h\((\(1\/2\) v\_x\^2 + \(g\_0\) 
                  y\ cos)\)\ \[DifferentialD]y\)\)], "Input"],

Cell["\<\
Express the energy in terms of Reynolds number and dimensional factors\
\>", "Text"],

Cell[BoxData[
    \(\(\(\(\(energy /. U \[Rule] Q\/\(h\ W\)\) /. 
              h \[Rule] \((\(3  \[Nu]\ Q\)\/\(\(g\_0\) \(W\)\(\ \)\(sin\)\(\ \
\)\))\)\^\(1/3\)\) /. 
            W \[Rule] \(\(\ \)\(Q\)\)\/\(\[Nu]\ R\)\) /. \[Nu] \[Rule] \(3  U\
\_0\^3\)\/\(\(g\_0\) sin\) // PowerExpand\) // Simplify\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Friction factor plot", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[CellGroupData[{

Cell["Constants", "Section"],

Cell["Choice of roughness", "Text"],

Cell[BoxData[{
    \(\(k = 10\^\(-3\);\)\), "\[IndentingNewLine]", 
    \(\(Lk = Log[10, k];\)\)}], "Input"],

Cell["Numerical  coefficients", "Text"],

Cell[BoxData[{
    \(\(As = 0.079;\)\), "\[IndentingNewLine]", 
    \(\(Ar = 0.028;\)\)}], "Input"],

Cell["Beginning of interval in Reynolds number", "Text"],

Cell[BoxData[{
    \(\(R0\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(LR0 = Log[10, R0] // N;\)\)}], "Input"],

Cell["Nominal transition point", "Text"],

Cell[BoxData[{
    \(\(R1 = 2300;\)\), "\[IndentingNewLine]", 
    \(\(LR1 = Log[10, R1] // N;\)\)}], "Input"],

Cell["Cross over between smooth and rough pipe", "Text"],

Cell[BoxData[
    \(R2 = \(\((As\/Ar)\)\^4\) 1\/k\)], "Input"],

Cell[BoxData[
    \(\(LR2 = Log[10, R2] // N;\)\)], "Input"],

Cell["End of Reynolds number interval", "Text"],

Cell[BoxData[{
    \(\(R3 = 10\^6;\)\), "\[IndentingNewLine]", 
    \(\(LR3 = Log[10, R3] // N;\)\)}], "Input"],

Cell["Logarithm of friction coefficient Cf for laminar flow", "Text"],

Cell[BoxData[
    \(\(CfLam = 16\/R;\)\)], "Input"],

Cell[BoxData[
    \(\(LCfLam = Log[10, CfLam] /. R \[Rule] 10\^LR;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Laminar flow plot (doubly logarithmic)", "Section"],

Cell["Simply a horizontal line", "Text"],

Cell[BoxData[
    \(\(fig1a = Plot[0, {LR, LR0, LR1}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Smooth pipe", "Section"],

Cell[BoxData[
    \(\(Cf = As\ R\^\(\(-1\)/4\);\)\)], "Input"],

Cell[BoxData[
    \(\(LCf = Log[10, Cf] /. R \[Rule] 10\^LR;\)\)], "Input"],

Cell[BoxData[
    \(\(Lf = LCf - LCfLam;\)\)], "Input"],

Cell[BoxData[
    \(\(fig1b = Plot[Lf, {LR, LR1, LR2}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rough pipe", "Section"],

Cell[BoxData[
    \(\(Cf = Ar\ k\^\(1/4\);\)\)], "Input"],

Cell[BoxData[
    \(\(LCf = Log[10, Cf] /. R \[Rule] 10\^LR;\)\)], "Input"],

Cell[BoxData[
    \(\(Lf = LCf - LCfLam;\)\)], "Input"],

Cell[BoxData[
    \(\(fig1c = Plot[Lf, {LR, LR2, LR3}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolation", "Section"],

Cell[BoxData[
    \(\(Cf = Ar \((63\/R + k)\)\^\(1/4\);\)\)], "Input"],

Cell[BoxData[
    \(\(LCf = Log[10, Cf] /. R \[Rule] 10\^LR;\)\)], "Input"],

Cell[BoxData[
    \(\(Lf = LCf - LCfLam;\)\)], "Input"],

Cell[BoxData[
    \(\(fig1d = 
        Plot[Lf, {LR, LR1, LR3}, PlotRange \[Rule] All, 
          PlotStyle \[Rule] {Dashing[{}], 
              Dashing[{0.005, 0.01}]}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lines and regions", "Section"],

Cell[BoxData[
    \(\(fig1e = 
        Show[Graphics[{Dashing[{0.001, 0.02}], Line[{{LR1, 0}, {LR1, 3}}], 
              Line[{{LR2, 0}, {LR2, 3}}], Text["\<laminar\>", {2.6, 2.5}], 
              Text["\<rough\>", {5.5, 2.5}], 
              Text["\<smooth\>", {4.1, 2.5}]}], 
          PlotRange \[Rule] All];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final plots", "Section"],

Cell[BoxData[
    \(\(ticks = Table[{n, "\<10\>"\^n}, {n, 0, 7}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, fig1b, fig1c, fig1d, fig1e, PlotRange \[Rule] All, 
          Frame \[Rule] True, FrameTicks \[Rule] {ticks, ticks, None, None}, 
          FrameLabel \[Rule] {"\<Re\>", "\<f(Re)\>"}] \
// \[IndentingNewLine]Figure["\<exact1\>"];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Title"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell[CellGroupData[{

Cell["18.2.1 Oil flow", "Section"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(\[Eta] = 
        2\ \(10\^\(-2\)\) Pascal\ Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho] = 800\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(d = 1\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(G = \ 10\^3\ Pascal/Meter;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\)}], "Input"],

Cell["Average velocity", "Text"],

Cell[BoxData[
    \(U = \ \(\(G\ d\^2\)\/\(12  \[Eta]\)\  // ToSI\) // N\)], "Input"],

Cell["Discharge rate", "Text"],

Cell[BoxData[
    \(QL = U\ d // ToUnit[\ \(Liter/Meter\)/Second]\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds = \(\[Rho]\ U\ d\)\/\[Eta] // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.3.1 Water film", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = 0.1\ Millimeter;\)\), "\[IndentingNewLine]", 
    \(\(\[Alpha] = 30  \[Degree];\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = 10\^\(-6\)\ Meter\^2/Second;\)\)}], "Input"],

Cell["Average velocity", "Text"],

Cell[BoxData[
    \(U = \(\(g\_0\) \(a\^2\) Sin[\[Alpha]]\)\/\(3  \[Nu]\) // 
        ToUnit[Millimeter]\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds = \ \(U\ a\)\/\[Nu] // ToSI\)], "Input"],

Cell["Condition for stability", "Text"],

Cell[BoxData[
    \(Reynolds\ Tan[\[Alpha]] < 5\/4\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.4.1. Aortic flow", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = 35\/2\ Millimeter;\)\), "\[IndentingNewLine]", 
    \(\(Q = 70. \ Milli\ Liter/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Eta] = 2.7*^-3\ Pascal\ Second\ ;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho] = 1000\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\)}], "Input"],

Cell["Average velocity", "Text"],

Cell[BoxData[
    \(U = Q\/\(\[Pi]\ a\^2\) // ToUnit[Centimeter/Second]\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds = \(\[Rho]\ 2\ a\ U\)\/\[Eta] // ToSI\)], "Input"],

Cell["Pressure gradient", "Text"],

Cell[BoxData[
    \(G = \(8  \[Eta]\ U\)\/a\^2 // ToUnit[Pascal]\)], "Input"],

Cell["Blood pressure", "Text"],

Cell[BoxData[
    \(p = \(120\/760\) Atmosphere // ToUnit[Pascal]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.4.2 Household water supply", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = 0.25\ Inch;\)\), "\[IndentingNewLine]", 
    \(\(Q = 0.1\ Liter/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Eta] = \ 10\^\(-3\)\ Pascal\ Second\ ;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho] = 1000\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\)}], "Input"],

Cell["Average velocity", "Text"],

Cell[BoxData[
    \(U = Q\/\(\[Pi]\ a\^2\) // ToSI\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds\  = \ \(\[Rho]\ 2\ a\ U\)\/\[Eta] // ToSI\)], "Input"],

Cell["Pressure gradient", "Text"],

Cell[BoxData[
    \(G = \(8\ \[Eta]\ U\)\/a\^2 // ToUnit[Pascal]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.4.3 Hypodermic syringe", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = 0.25\ Millimeter;\)\), "\[IndentingNewLine]", 
    \(\(b = 0.5\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(L = 5\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(M = 5\ Gram;\)\), "\n", 
    \(\(Q = \ 0.5\ Milli\ Liter/Second;\)\), "\n", 
    \(\(\[Eta] = \ \(10\^\(-3\)\) 
          Pascal\ Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho] = \(10\^3\) Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\)}], "Input"],

Cell["Kinematic viscosity", "Text"],

Cell[BoxData[
    \(\(\[Nu] = \[Eta]\/\[Rho]\ ;\)\)], "Input"],

Cell[CellGroupData[{

Cell["Needle", "Subsection"],

Cell["Needle cross section", "Text"],

Cell[BoxData[
    \(\(A = \[Pi]\ a\^2;\)\)], "Input"],

Cell["Average needle velocity", "Text"],

Cell[BoxData[
    \(U = \ \(\(Q\/A\)\(//\)\(ToSI\)\(\ \ \)\)\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds = \(U\ 2  a\)\/\[Nu] // ToSI\)], "Input"],

Cell["Pressure gradient in needle", "Text"],

Cell[BoxData[
    \(G = \(8  \[Eta]\ U\)\/a\^2 // ToUnit[Bar]\)], "Input"],

Cell["Pressure drop in needle", "Text"],

Cell[BoxData[
    \(\[CapitalDelta]p = L\ G // ToUnit[Bar]\)], "Input"],

Cell["Viscous drag", "Text"],

Cell[BoxData[
    \(drag\  = \ \[CapitalDelta]p\ A // ToUnit[Newton]\)], "Input"],

Cell["Momentum transfer rate", "Text"],

Cell[BoxData[
    \(momentumrate = \[Rho]\ U\ Q // ToUnit[Newton]\)], "Input"],

Cell["Power", "Text"],

Cell[BoxData[
    \(P = \[CapitalDelta]p\ Q // ToUnit[Milli\ Watt]\)], "Input"],

Cell["Average specific rate of dissipation", "Text"],

Cell[BoxData[
    \(\[Epsilon] = 8\ \[Nu]\ U\^2\/a\^2 // ToUnit[Watt/Kilogram]\)], "Input"],

Cell["Specific heat capacity of water", "Text"],

Cell[BoxData[
    \(\(c\_P = 1\ \(Calorie/Kelvin\)/Gram;\)\)], "Input"],

Cell["Temperature raise", "Text"],

Cell[BoxData[
    \(\[CapitalDelta]T = 
      P\/\(\(c\_P\) \[Rho]\ Q\) // ToUnit[Milli\ Kelvin]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Chamber", "Subsection"],

Cell["Area of chamber", "Text"],

Cell[BoxData[
    \(\(B = \[Pi]\ b\^2;\)\)], "Input"],

Cell["Average velocity in chamber", "Text"],

Cell[BoxData[
    \(U\_0 = \ Q\/B // ToUnit[Centimeter]\)], "Input"],

Cell["Force on piston", "Text"],

Cell[BoxData[
    \(F = \(\(\[CapitalDelta]p\ B\)\(//\)\(ToUnit[
          Newton]\)\(\ \)\)\)], "Input"],

Cell["Power check", "Text"],

Cell[BoxData[
    \(F\ U\_0 // ToUnit[Milli\ Watt]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.5.3 Barrel of wine", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(L = 20\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(a = 2.5\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(h = 2\ Meter;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = \(10\^\(-6\)\) Meter\^2/Second;\)\), "\[IndentingNewLine]", 
    \(\(k = 0.5\ Millimeter;\)\)}], "Input"],

Cell["Velocity", "Text"],

Cell[BoxData[
    \(U\_0 = \@\(2 \( g\_0\) h\) // ToSI\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Re\_0 = \(2\ a\ U\_0\)\/\[Nu] // ToSI\)], "Input"],

Cell["Terminal friction coefficient", "Text"],

Cell[BoxData[
    \(Cf = 0.028 \((k\/\(2  a\))\)\^\(1/4\) // ToSI\)], "Input"],

Cell["Friction correction", "Text"],

Cell[BoxData[
    \(\(\(4\ Cf\ L\/\(2  a\)\)\(//\)\(ToSI\)\(\ \)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.6.1 Burning bush", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(\[Eta] = 10\ Pascal\ Second;\)\), "\[IndentingNewLine]", 
    \(\(a = 5\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(d\  = \ 1\ Millimeter;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalOmega] = 2\ \[Pi]\ /Second;\)\)}], "Input"],

Cell["Power density", "Text"],

Cell[BoxData[
    \(\[Epsilon] = \ \(\(\[Eta]\ \(\[CapitalOmega]\^2\) a\^2\)\/d\^2 // N\) // 
        ToUnit[Joule/\((Centimeter)\)\^3]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Title"],

Cell[CellGroupData[{

Cell["18.8 Vertical water pipe", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters for water", "Text"],

Cell[BoxData[{
    \(\(\[Nu] = \(10\^\(-6\)\) Meter\^2/Second;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\)}], "Input"],

Cell["Radius for Re=1", "Text"],

Cell[BoxData[
    \(a = \((\(4  \[Nu]\^2\)\/g\_0)\)\^\(1/3\) // 
        ToUnit[Micrometer]\)], "Input"],

Cell["Radius at the transition to turbulence", "Text"],

Cell[BoxData[
    \(a*2300\^\(1/3\) // ToUnit[Millimeter]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.17 Couette flow", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\(v\_\[Phi]\  = \(\(\(a\^2\) \[CapitalOmega]\)\/r\) \(b\^2 - \
r\^2\)\/\(b\^2 - a\^2\);\)\)], "Input"],

Cell[BoxData[
    \(Q = \[Integral]\_a\%b v\_\[Phi]\ L\ \[DifferentialD]r // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(T = \[Integral]\_a\%b\( 1\/2\) \(\[Rho]\_0\) 
            v\_\[Phi]\^2\ L\ 2  \[Pi]\ r\ \[DifferentialD]r // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(T/\((\[Pi]\ \(\[Rho]\_0\) 
            L\ \(a\^4\) \(b\^4\) \[CapitalOmega]\^2/\((b\^2 - a\^2)\)\^2)\) // 
      Simplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["18.20 Drive shaft", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = 1\/2*15\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(L = 10\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(d = 1\ Millimeter;\)\), "\[IndentingNewLine]", 
    \(\(\[Eta] = 0.01\ Pascal\ Second;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalOmega] = 10*2  \[Pi]\ /Second;\)\)}], "Input"],

Cell["Power", "Text"],

Cell[BoxData[
    \(P = 
      2  \[Pi]\ \[Eta]\ \(\[CapitalOmega]\^2\) \(a\^3\) L\/d // 
        ToUnit[Watt]\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 937}},
AutoGeneratedPackage->None,
WindowSize->{736, 903},
WindowMargins->{{121, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 67, 1, 95, "Title",
  InitializationCell->True],
Cell[1846, 56, 129, 3, 50, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[2012, 64, 34, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[2071, 68, 38, 0, 73, "Section"],
Cell[2112, 70, 46, 1, 30, "Input"],
Cell[2161, 73, 30, 0, 33, "Text"],
Cell[2194, 75, 80, 1, 42, "Input"],
Cell[2277, 78, 22, 0, 33, "Text"],
Cell[2302, 80, 153, 3, 42, "Input"],
Cell[2458, 85, 94, 2, 33, "Text"],
Cell[2555, 89, 315, 5, 69, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2919, 100, 37, 0, 95, "Title"],
Cell[2959, 102, 46, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[3030, 107, 28, 0, 73, "Section"],
Cell[3061, 109, 35, 0, 33, "Text"],
Cell[3099, 111, 108, 2, 50, "Input"],
Cell[3210, 115, 39, 0, 33, "Text"],
Cell[3252, 117, 99, 2, 50, "Input"],
Cell[3354, 121, 56, 0, 33, "Text"],
Cell[3413, 123, 113, 2, 50, "Input"],
Cell[3529, 127, 40, 0, 33, "Text"],
Cell[3572, 129, 110, 2, 50, "Input"],
Cell[3685, 133, 56, 0, 33, "Text"],
Cell[3744, 135, 62, 1, 43, "Input"],
Cell[3809, 138, 60, 1, 30, "Input"],
Cell[3872, 141, 47, 0, 33, "Text"],
Cell[3922, 143, 111, 2, 50, "Input"],
Cell[4036, 147, 69, 0, 33, "Text"],
Cell[4108, 149, 51, 1, 42, "Input"],
Cell[4162, 152, 81, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4280, 158, 57, 0, 73, "Section"],
Cell[4340, 160, 40, 0, 33, "Text"],
Cell[4383, 162, 69, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4489, 168, 30, 0, 73, "Section"],
Cell[4522, 170, 62, 1, 30, "Input"],
Cell[4587, 173, 75, 1, 30, "Input"],
Cell[4665, 176, 55, 1, 30, "Input"],
Cell[4723, 179, 70, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4830, 185, 29, 0, 73, "Section"],
Cell[4862, 187, 57, 1, 30, "Input"],
Cell[4922, 190, 75, 1, 30, "Input"],
Cell[5000, 193, 55, 1, 30, "Input"],
Cell[5058, 196, 70, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5165, 202, 32, 0, 73, "Section"],
Cell[5200, 204, 70, 1, 43, "Input"],
Cell[5273, 207, 75, 1, 30, "Input"],
Cell[5351, 210, 55, 1, 30, "Input"],
Cell[5409, 213, 185, 4, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5631, 222, 36, 0, 73, "Section"],
Cell[5670, 224, 326, 6, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6033, 235, 30, 0, 73, "Section"],
Cell[6066, 237, 80, 1, 30, "Input"],
Cell[6149, 240, 278, 4, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6476, 250, 25, 0, 95, "Title"],
Cell[6504, 252, 51, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[6580, 257, 34, 0, 73, "Section"],
Cell[6617, 259, 26, 0, 33, "Text"],
Cell[6646, 261, 350, 6, 110, "Input"],
Cell[6999, 269, 32, 0, 33, "Text"],
Cell[7034, 271, 85, 1, 47, "Input"],
Cell[7122, 274, 30, 0, 33, "Text"],
Cell[7155, 276, 78, 1, 30, "Input"],
Cell[7236, 279, 31, 0, 33, "Text"],
Cell[7270, 281, 76, 1, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7383, 287, 36, 0, 73, "Section"],
Cell[7422, 289, 46, 1, 30, "Input"],
Cell[7471, 292, 26, 0, 33, "Text"],
Cell[7500, 294, 266, 4, 90, "Input"],
Cell[7769, 300, 32, 0, 33, "Text"],
Cell[7804, 302, 117, 2, 46, "Input"],
Cell[7924, 306, 31, 0, 33, "Text"],
Cell[7958, 308, 69, 1, 42, "Input"],
Cell[8030, 311, 39, 0, 33, "Text"],
Cell[8072, 313, 63, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8172, 319, 38, 0, 73, "Section"],
Cell[8213, 321, 46, 1, 30, "Input"],
Cell[8262, 324, 26, 0, 33, "Text"],
Cell[8291, 326, 343, 5, 123, "Input"],
Cell[8637, 333, 32, 0, 33, "Text"],
Cell[8672, 335, 84, 1, 43, "Input"],
Cell[8759, 338, 31, 0, 33, "Text"],
Cell[8793, 340, 79, 1, 44, "Input"],
Cell[8875, 343, 33, 0, 33, "Text"],
Cell[8911, 345, 77, 1, 42, "Input"],
Cell[8991, 348, 30, 0, 33, "Text"],
Cell[9024, 350, 78, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9139, 356, 48, 0, 73, "Section"],
Cell[9190, 358, 46, 1, 30, "Input"],
Cell[9239, 361, 26, 0, 33, "Text"],
Cell[9268, 363, 333, 5, 110, "Input"],
Cell[9604, 370, 32, 0, 33, "Text"],
Cell[9639, 372, 63, 1, 43, "Input"],
Cell[9705, 375, 31, 0, 33, "Text"],
Cell[9739, 377, 83, 1, 44, "Input"],
Cell[9825, 380, 33, 0, 33, "Text"],
Cell[9861, 382, 77, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9975, 388, 44, 0, 73, "Section"],
Cell[10022, 390, 46, 1, 30, "Input"],
Cell[10071, 393, 26, 0, 33, "Text"],
Cell[10100, 395, 494, 9, 170, "Input"],
Cell[10597, 406, 35, 0, 33, "Text"],
Cell[10635, 408, 62, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[10722, 413, 28, 0, 38, "Subsection"],
Cell[10753, 415, 36, 0, 33, "Text"],
Cell[10792, 417, 53, 1, 30, "Input"],
Cell[10848, 420, 39, 0, 33, "Text"],
Cell[10890, 422, 73, 1, 42, "Input"],
Cell[10966, 425, 31, 0, 33, "Text"],
Cell[11000, 427, 70, 1, 42, "Input"],
Cell[11073, 430, 43, 0, 33, "Text"],
Cell[11119, 432, 74, 1, 42, "Input"],
Cell[11196, 435, 39, 0, 33, "Text"],
Cell[11238, 437, 71, 1, 30, "Input"],
Cell[11312, 440, 28, 0, 33, "Text"],
Cell[11343, 442, 81, 1, 30, "Input"],
Cell[11427, 445, 38, 0, 33, "Text"],
Cell[11468, 447, 78, 1, 30, "Input"],
Cell[11549, 450, 21, 0, 33, "Text"],
Cell[11573, 452, 79, 1, 30, "Input"],
Cell[11655, 455, 52, 0, 33, "Text"],
Cell[11710, 457, 91, 1, 45, "Input"],
Cell[11804, 460, 47, 0, 33, "Text"],
Cell[11854, 462, 71, 1, 30, "Input"],
Cell[11928, 465, 33, 0, 33, "Text"],
Cell[11964, 467, 109, 2, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12110, 474, 29, 0, 38, "Subsection"],
Cell[12142, 476, 31, 0, 33, "Text"],
Cell[12176, 478, 53, 1, 30, "Input"],
Cell[12232, 481, 43, 0, 33, "Text"],
Cell[12278, 483, 68, 1, 42, "Input"],
Cell[12349, 486, 31, 0, 33, "Text"],
Cell[12383, 488, 105, 2, 30, "Input"],
Cell[12491, 492, 27, 0, 33, "Text"],
Cell[12521, 494, 63, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12633, 501, 40, 0, 73, "Section"],
Cell[12676, 503, 46, 1, 30, "Input"],
Cell[12725, 506, 26, 0, 33, "Text"],
Cell[12754, 508, 372, 6, 130, "Input"],
Cell[13129, 516, 24, 0, 33, "Text"],
Cell[13156, 518, 67, 1, 32, "Input"],
Cell[13226, 521, 31, 0, 33, "Text"],
Cell[13260, 523, 70, 1, 42, "Input"],
Cell[13333, 526, 45, 0, 33, "Text"],
Cell[13381, 528, 78, 1, 44, "Input"],
Cell[13462, 531, 35, 0, 33, "Text"],
Cell[13500, 533, 79, 1, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13616, 539, 38, 0, 73, "Section"],
Cell[13657, 541, 51, 1, 30, "Input"],
Cell[13711, 544, 26, 0, 33, "Text"],
Cell[13740, 546, 257, 4, 90, "Input"],
Cell[14000, 552, 29, 0, 33, "Text"],
Cell[14032, 554, 148, 2, 45, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14229, 562, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[14279, 566, 43, 0, 73, "Section"],
Cell[14325, 568, 46, 1, 30, "Input"],
Cell[14374, 571, 36, 0, 33, "Text"],
Cell[14413, 573, 148, 2, 50, "Input"],
Cell[14564, 577, 31, 0, 33, "Text"],
Cell[14598, 579, 104, 2, 48, "Input"],
Cell[14705, 583, 54, 0, 33, "Text"],
Cell[14762, 585, 70, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14869, 591, 37, 0, 73, "Section"],
Cell[14909, 593, 46, 1, 30, "Input"],
Cell[14958, 596, 122, 2, 45, "Input"],
Cell[15083, 600, 107, 2, 42, "Input"],
Cell[15193, 604, 159, 3, 42, "Input"],
Cell[15355, 609, 154, 3, 32, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15546, 617, 36, 0, 73, "Section"],
Cell[15585, 619, 46, 1, 30, "Input"],
Cell[15634, 622, 26, 0, 33, "Text"],
Cell[15663, 624, 321, 5, 123, "Input"],
Cell[15987, 631, 21, 0, 33, "Text"],
Cell[16011, 633, 123, 3, 42, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

