(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14386,        484]*)
(*NotebookOutlinePosition[     15122,        509]*)
(*  CellTagsIndexPosition[     15078,        505]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["19. Creeping flow", "Title"],

Cell[BoxData[{
    \(<< Lautrup`\), "\n", 
    \(<< Graphics`\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Streamlines for Stokes solution", "Title"],

Cell["See also problem 19.7 for another solution", "Text"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Basic functions", "Text"],

Cell[BoxData[{
    \(\(r = \@\(z\^2 + x\^2\);\)\), "\n", 
    \(\(A = 1 - 3\/\(2  r\) + 1\/\(2  r\^3\);\)\), "\n", 
    \(\(B = 1 - 3\/\(4  r\) - 1\/\(4  r\^3\);\)\)}], "Input"],

Cell["Right hand side of differential equation  ds/dz= rhs", "Text"],

Cell[BoxData[
    \(rhs[x_, z_] = \(\((A - B)\) x\ z\)\/\(A\ z\^2 + B\ x\^2\) // 
        Simplify\)], "Input"],

Cell["Solve differential equation ", "Text"],

Cell[BoxData[
    \(sol[z0_, x0_] := 
      NDSolve[{\(f'\)[z] \[Equal] rhs[f[z], z], f[\(-z0\)] \[Equal] x0}, 
        f[z], {z, \(-z0\), z0}]\)], "Input"],

Cell["Table of streamlines", "Text"],

Cell[BoxData[
    \(\(stream = 
        Table[f[z] /. \(sol[100, x0]\)[\([1]\)], {x0, 0, 3, 
            0.2}];\)\)], "Input"],

Cell["Make plot", "Text"],

Cell[BoxData[
    \(\(fig1a = 
        Plot[stream // Evaluate, {z, \(-3\), 3}, Frame -> True, 
          PlotRange -> {{\(-3\), 3}, {0, 3}}, 
          Axes \[Rule] False];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1b = 
        Graphics[{GrayLevel[0.5], Disk[{0, 0}, 1], Dashing[{0.01}], 
            Line[{{0, 1}, {0, 3}}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, fig1b, 
          AspectRatio \[Rule] 
            1\/2] // \[IndentingNewLine]Figure["\<creep1\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Drag coefficient", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Simple interpolation", "Text"],

Cell[BoxData[
    \(\(cd[r_] = 24\/r + 6\/\@r + 0.3;\)\)], "Input"],

Cell[BoxData[
    \(\(ticks = {{\(-1\), 0.1}} \[Union] \ 
          Table[{n, "\<10\>"\^n}, {n, 0, 10}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig2a = 
        Plot[Log[10, cd[10\^x]], {x, \(-1.1\), 6}, 
          PlotRange \[Rule] {{\(-1.2\), 6}, {\(-1.2\), 3}}, 
          AxesOrigin \[Rule] {\(-1.2\), \(-1.2\)}, 
          Ticks \[Rule] {ticks, ticks}, 
          PlotStyle \[Rule] Dashing[{0.01, 0.02}], 
          AxesLabel \[Rule] {"\<Re\>", \*"\"\<\!\(C\_D\)\>\""}];\)\)], "Input"],

Cell["Laminar drag coefficient", "Text"],

Cell[BoxData[
    \(\(fig2b = 
        Plot[Log[10, 24\/10\^x], {x, \(-1.2\), 1.5}, 
          PlotStyle \[Rule] Dashing[{0.01, 0.02}]];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Data from Schlichting fig. 1.19", "Section"],

Cell[BoxData[
    \(\(data = {{5.6662, \(-1.0221\)}, {5.6171, \(-1.0221\)}, {5.568, \
\(-1.0221\)}, {5.5288, \(-0.9745\)}, {5.4895, \(-0.9555\)}, {5.4698, \
\(-0.8128\)}, {5.46, \(-0.7272\)}, {5.4404, \(-0.6321\)}, {5.4306, \
\(-0.556\)}, {5.4109, \(-0.4609\)}, {5.4011, \(-0.3657\)}, {5.352, \
\(-0.3753\)}, {5.3128, \(-0.3657\)}, {5.2637, \(-0.3467\)}, {5.1851, \
\(-0.3372\)}, {5.1066, \(-0.3372\)}, {5.0182, \(-0.3182\)}, {4.9201, \
\(-0.2706\)}, {4.8219, \(-0.2706\)}, {4.7532, \(-0.2801\)}, {4.6746, \
\(-0.3087\)}, {4.5961, \(-0.2897\)}, {4.4979, \(-0.3087\)}, {4.439, \(-0.2801\
\)}, {4.3604, \(-0.3182\)}, {4.2917, \(-0.3182\)}, {4.223, \(-0.3372\)}, \
{4.1248, \(-0.3562\)}, {3.9972, \(-0.3657\)}, {3.899, \(-0.3753\)}, {3.899, \
\(-0.3182\)}, {3.8107, \(-0.3848\)}, {3.7714, \(-0.3467\)}, {3.7027, \
\(-0.3943\)}, {3.6241, \(-0.3657\)}, {3.575, \(-0.3848\)}, {3.5259, \(-0.3657\
\)}, {3.4572, \(-0.3848\)}, {3.359, \(-0.4038\)}, {3.3492, \(-0.2992\)}, \
{3.31, \(-0.3657\)}, {3.3001, \(-0.3182\)}, {3.0645, \(-0.4133\)}, {3.0351, \
\(-0.3467\)}, {2.9173, \(-0.2706\)}, {2.8191, \(-0.2421\)}, {2.77, \
\(-0.1565\)}, {2.6816, \(-0.204\)}, {2.5049, \(-0.1755\)}, {2.3773, \(-0.0804\
\)}, {2.1515, 0.0147}, {1.9551, 0.1099}, {1.8962, 0.1194}, {1.7195, 
            0.224}, {1.5231, 0.3477}, {1.4053, 0.4238}, {1.3562, 
            0.4143}, {1.317, 0.4523}, {1.3072, 0.5094}, {1.1893, 
            0.5569}, {1.1206, 0.614}, {1.0912, 0.576}, {1.0224, 
            0.6901}, {0.885, 0.7757}, {0.8261, 0.8328}, {0.6788, 
            0.9184}, {0.6003, 0.9945}, {0.5119, 1.0516}, {0.453, 
            1.1182}, {0.3941, 1.1467}, {0.2076, 1.2799}, {0.1192, 
            1.3655}, {0.0603, 1.4511}, {\(-0.0182\), 1.5177}, {\(-0.1262\), 
            1.6128}, {\(-0.1753\), 1.6508}, {\(-0.2735\), 
            1.7364}, {\(-0.4895\), 1.9267}, {\(-0.6171\), 
            2.0694}, {\(-0.7349\), 2.2025}, {\(-0.7742\), 
            2.2406}, {\(-0.8429\), 2.2786}, {\(-0.9607\), 2.4308}, {\(-1. \), 
            2.4499}};\)\)], "Input"],

Cell["Make plot", "Text"],

Cell[BoxData[
    \(\(fig2c = 
        ListPlot[data, PlotStyle \[Rule] PointSize[0.01]];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig2a, fig2b, 
          fig2c] // \[IndentingNewLine]Figure["\<creep2\>"];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Title"],

Cell[CellGroupData[{

Cell["19.2.1 Sedimentation of sand grains", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = \(1\/2\) 0.1  Millimeter;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_0 = 1000\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_1 = 2.5\ \[Rho]\_0;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = \(10\^\(-6\)\) Meter\^2/Second;\)\)}], "Input"],

Cell["Terminal velocity", "Text"],

Cell[BoxData[
    \(U = \(2\/9\) \((\[Rho]\_1\/\[Rho]\_0 - 1)\) \(\(a\^2\) g\_0\)\/\[Nu] // 
        ToUnit[Centimeter]\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds = \(U\ 2  a\)\/\[Nu] // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["19.3.1 Falling skydiver", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = 50\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = 
        1.6\ \(10\^\(-5\)\) Meter\^2/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_1 = 1\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(m = 70\ Kilogram;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(C\_D = 0.3;\)\)}], "Input"],

Cell["\<\
Skydiver density (lower than water because of spherical approximation!)\
\>", "Text"],

Cell[BoxData[
    \(\[Rho]\_0 = \ \(m\/\(\(4\/3\) \[Pi]\ a\^3\) // ToUnit[Kilogram]\) // 
        N\)], "Input"],

Cell["Terminal speed", "Text"],

Cell[BoxData[
    \(U = \@\(\(8\/3\) \((\[Rho]\_0\/\[Rho]\_1 - 1)\)\ \(a\ g\_0\)\/C\_D\) // 
        ToUnit[Meter]\)], "Input"],

Cell[BoxData[
    \(U // ToUnit[Kilometer/Hour]\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds = \(2  a\ U\)\/\[Nu] // ToSI\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Title"],

Cell[CellGroupData[{

Cell["19.1 Sedimentation in the sea", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = \(1\/2\) 10  Micrometer;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_0 = 1000\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_1 = 1.2\ \[Rho]\_0;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = \(10\^\(-6\)\) Meter\^2/Second;\)\), "\[IndentingNewLine]", 
    \(\(d = 4\ Kilometer;\)\)}], "Input"],

Cell["Terminal speed", "Text"],

Cell[BoxData[
    \(U = \(2\/9\) \((\[Rho]\_1\/\[Rho]\_0 - 1)\) \(\(a\^2\) g\_0\)\/\[Nu] // 
        ToUnit[Micrometer]\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds = \(U\ 2  a\)\/\[Nu] // ToSI\)], "Input"],

Cell["Settling time", "Text"],

Cell[BoxData[
    \(t = d\/U // ToUnit[Year]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["19.2 Settling in the atmosphere", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = \(1\/2\) Micrometer;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_0 = 1.2\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_1 = 2500\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(\[Eta]\_0 = 1.8*^-5\ Pascal\ Second;\)\), "\[IndentingNewLine]", 
    \(\(z = 10\ Kilometer;\)\), "\[IndentingNewLine]", 
    \(\(h\_2 = 30\ Kilometer;\)\)}], "Input"],

Cell["Settling time", "Text"],

Cell[BoxData[
    \(t\_0 = \(\(3 \( \[Eta]\_0\) h\_2\)\/\(\(\[Rho]\_1\) \(a\^2\) 
                g\_0\)\) \((1 - \((1 - z\/h\_2)\)\^\(3/2\))\) // 
        ToUnit[Year]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["19.7 Streamlines for Stokes solution", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["\<\
Solve basic equation with s=d/Sin \[Theta]\
\>", "Text"],

Cell[BoxData[
    \(f[s_] := 
      r /. Solve[\((r - 1)\) \@\(1 + 1\/\(2  r\)\) \[Equal] s, r] // 
        First\)], "Input"],

Cell["Create function interpolation to save time", "Text"],

Cell[BoxData[
    \(g = FunctionInterpolation[f[s], {s, 10\^\(-6\), 40}]\)], "Input"],

Cell["Cartesian coordinates", "Text"],

Cell[BoxData[{
    \(\(x[d_] := 
        g[d\/Sin[\[Theta]]]\ Sin[\[Theta]];\)\), "\[IndentingNewLine]", 
    \(\(z[d_] := g[d\/Sin[\[Theta]]] Cos[\[Theta]];\)\)}], "Input"],

Cell["Make table of streamlines", "Text"],

Cell[BoxData[
    \(\(stream = Table[{z[d], x[d]}, {d, 0.2, 3, 0.2}];\)\)], "Input"],

Cell["Polar angle cut-off", "Text"],

Cell[BoxData[
    \(\(\[Epsilon] = 0.095;\)\)], "Input"],

Cell["Make plot", "Text"],

Cell[BoxData[
    \(\(fig1a = 
        ParametricPlot[
          stream // Evaluate, {\[Theta], \[Epsilon], \[Pi] - \[Epsilon]}, 
          PlotRange \[Rule] {{\(-3\), 3}, {0, 3}}, Frame \[Rule] True, 
          AspectRatio \[Rule] 1/2];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1b = 
        Graphics[{GrayLevel[0.5], Disk[{0, 0}, 1], Dashing[{0.01}], 
            Line[{{0, 1}, {0, 3}}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, fig1b];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["19.10 Analytic solution of Stokes flow for a sphere", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Coordinate system", "Text"],

Cell[BoxData[
    \(\(SetCoordinates[Spherical[r, \[Theta], \[Phi]]];\)\)], "Input"],

Cell["Define fields", "Text"],

Cell[BoxData[{
    \(\(v\_r = \((a[r] + \(\(\(r\)\(\ \)\)\^2\) b[r])\) 
          U\ \ Cos[\[Theta]];\)\), "\[IndentingNewLine]", 
    \(\(v\_\[Theta] = \(-a[
              r]\)\ U\ Sin[\[Theta]];\)\), "\[IndentingNewLine]", 
    \(\(v\_\[Phi] = 0;\)\), "\[IndentingNewLine]", 
    \(\(p = \[Eta]\ c[r] U\ \ r\ Cos[\[Theta]];\)\)}], "Input"],

Cell[BoxData[
    \(\(\[Eta] = \(\[Rho]\_0\) \[Nu];\)\)], "Input"],

Cell["Insert into NS-equations", "Text"],

Cell[BoxData[
    \(\(v = {v\_r, v\_\[Theta], v\_\[Phi]};\)\)], "Input"],

Cell[BoxData[
    \(NS = \(-\(Grad[p]\/\[Rho]\_0\)\) + \[Nu]\ Laplacian[v] // 
        TrigExpand\)], "Input"],

Cell["And the divergence equation", "Text"],

Cell[BoxData[
    \(DC = Div[v] // TrigExpand\)], "Input"],

Cell["Simplify", "Text"],

Cell[BoxData[
    \(NS1 = 
      NS[\([1]\)]/\((\(r\^\(\(2\)\(\ \)\)\) \[Nu]\ U\ Cos[\[Theta]])\) // 
        Expand\)], "Input"],

Cell[BoxData[
    \(NS2 = NS[\([2]\)]/\((\[Nu]\ U\ Sin[\[Theta]])\) // Expand\)], "Input"],

Cell[BoxData[
    \(NS3 = DC/\((\ r\ U\ Cos[\[Theta]])\) // Expand\)], "Input"],

Cell["This is a better combination", "Text"],

Cell[BoxData[
    \(NS1a = NS1 + NS2\/r\^2 // Expand\)], "Input"],

Cell["Make ansatz and insert", "Text"],

Cell[BoxData[
    \(a[r_] = A\ r\^\[Alpha]; \ b[r_] = B\ r\^\[Beta]; \ 
    c[r_] = CC\ r\^\[Gamma];\)], "Input"],

Cell[BoxData[
    \(\(NS1a // Expand\) // Collect[#, r\^_] &\)], "Input"],

Cell[BoxData[
    \(\(NS2 // Expand\) // Collect[#, r\^_] &\)], "Input"],

Cell[BoxData[
    \(\(NS3 // Expand\) // Collect[#, r\^_] &\)], "Input"],

Cell["Solution", "Text"],

Cell[BoxData[
    \(\(\[Beta] = \(\[Gamma] = \[Alpha] - 2\);\)\)], "Input"],

Cell[BoxData[
    \(E1 = NS1a/r\^\(\[Beta] - 2\) // Simplify\)], "Input"],

Cell[BoxData[
    \(E2 = NS2/r\^\[Beta] // Simplify\)], "Input"],

Cell[BoxData[
    \(E3 = NS3/r\^\[Beta] // Simplify\)], "Input"],

Cell["Get determinant", "Text"],

Cell[BoxData[
    \(\(\((\[Alpha] + 2)\)/A*
            E1 /. \(Solve[{E2 \[Equal] 0, E3 \[Equal] 0}, {B, 
                CC}]\)[\([1]\)] // Simplify\) // Factor\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
AutoGeneratedPackage->None,
WindowSize->{804, 903},
WindowMargins->{{Automatic, 97}, {-17, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 34, 0, 95, "Title"],
Cell[1813, 55, 103, 3, 50, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[1953, 63, 48, 0, 95, "Title"],
Cell[2004, 65, 58, 0, 33, "Text"],
Cell[2065, 67, 46, 1, 30, "Input"],
Cell[2114, 70, 31, 0, 33, "Text"],
Cell[2148, 72, 177, 3, 102, "Input"],
Cell[2328, 77, 68, 0, 33, "Text"],
Cell[2399, 79, 111, 2, 43, "Input"],
Cell[2513, 83, 44, 0, 33, "Text"],
Cell[2560, 85, 156, 3, 30, "Input"],
Cell[2719, 90, 36, 0, 33, "Text"],
Cell[2758, 92, 126, 3, 30, "Input"],
Cell[2887, 97, 25, 0, 33, "Text"],
Cell[2915, 99, 188, 4, 30, "Input"],
Cell[3106, 105, 152, 3, 30, "Input"],
Cell[3261, 110, 149, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3447, 118, 33, 0, 95, "Title"],
Cell[3483, 120, 46, 1, 30, "Input"],
Cell[3532, 123, 36, 0, 33, "Text"],
Cell[3571, 125, 67, 1, 48, "Input"],
Cell[3641, 128, 119, 2, 30, "Input"],
Cell[3763, 132, 368, 7, 70, "Input"],
Cell[4134, 141, 40, 0, 33, "Text"],
Cell[4177, 143, 151, 3, 42, "Input"],

Cell[CellGroupData[{
Cell[4353, 150, 50, 0, 73, "Section"],
Cell[4406, 152, 2025, 29, 390, "Input"],
Cell[6434, 183, 25, 0, 33, "Text"],
Cell[6462, 185, 104, 2, 30, "Input"],
Cell[6569, 189, 117, 2, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6735, 197, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[6785, 201, 54, 0, 73, "Section"],
Cell[6842, 203, 46, 1, 30, "Input"],
Cell[6891, 206, 26, 0, 33, "Text"],
Cell[6920, 208, 354, 5, 123, "Input"],
Cell[7277, 215, 33, 0, 33, "Text"],
Cell[7313, 217, 132, 2, 47, "Input"],
Cell[7448, 221, 31, 0, 33, "Text"],
Cell[7482, 223, 70, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7589, 229, 42, 0, 73, "Section"],
Cell[7634, 231, 46, 1, 30, "Input"],
Cell[7683, 234, 26, 0, 33, "Text"],
Cell[7712, 236, 394, 7, 130, "Input"],
Cell[8109, 245, 95, 2, 33, "Text"],
Cell[8207, 249, 112, 2, 49, "Input"],
Cell[8322, 253, 30, 0, 33, "Text"],
Cell[8355, 255, 127, 2, 51, "Input"],
Cell[8485, 259, 60, 1, 30, "Input"],
Cell[8548, 262, 31, 0, 33, "Text"],
Cell[8582, 264, 70, 1, 42, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8701, 271, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[8751, 275, 48, 0, 73, "Section"],
Cell[8802, 277, 46, 1, 30, "Input"],
Cell[8851, 280, 26, 0, 33, "Text"],
Cell[8880, 282, 408, 6, 143, "Input"],
Cell[9291, 290, 30, 0, 33, "Text"],
Cell[9324, 292, 132, 2, 47, "Input"],
Cell[9459, 296, 31, 0, 33, "Text"],
Cell[9493, 298, 70, 1, 42, "Input"],
Cell[9566, 301, 29, 0, 33, "Text"],
Cell[9598, 303, 57, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9692, 309, 50, 0, 73, "Section"],
Cell[9745, 311, 46, 1, 30, "Input"],
Cell[9794, 314, 26, 0, 33, "Text"],
Cell[9823, 316, 469, 7, 163, "Input"],
Cell[10295, 325, 29, 0, 33, "Text"],
Cell[10327, 327, 181, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10545, 335, 55, 0, 73, "Section"],
Cell[10603, 337, 46, 1, 30, "Input"],
Cell[10652, 340, 66, 2, 33, "Text"],
Cell[10721, 344, 126, 3, 51, "Input"],
Cell[10850, 349, 58, 0, 33, "Text"],
Cell[10911, 351, 85, 1, 31, "Input"],
Cell[10999, 354, 37, 0, 33, "Text"],
Cell[11039, 356, 173, 3, 80, "Input"],
Cell[11215, 361, 41, 0, 33, "Text"],
Cell[11259, 363, 84, 1, 30, "Input"],
Cell[11346, 366, 35, 0, 33, "Text"],
Cell[11384, 368, 56, 1, 30, "Input"],
Cell[11443, 371, 25, 0, 33, "Text"],
Cell[11471, 373, 252, 5, 50, "Input"],
Cell[11726, 380, 152, 3, 30, "Input"],
Cell[11881, 385, 56, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11974, 391, 70, 0, 73, "Section"],
Cell[12047, 393, 46, 1, 30, "Input"],
Cell[12096, 396, 33, 0, 33, "Text"],
Cell[12132, 398, 84, 1, 30, "Input"],
Cell[12219, 401, 29, 0, 33, "Text"],
Cell[12251, 403, 341, 6, 91, "Input"],
Cell[12595, 411, 66, 1, 30, "Input"],
Cell[12664, 414, 40, 0, 33, "Text"],
Cell[12707, 416, 72, 1, 30, "Input"],
Cell[12782, 419, 110, 2, 44, "Input"],
Cell[12895, 423, 43, 0, 33, "Text"],
Cell[12941, 425, 58, 1, 30, "Input"],
Cell[13002, 428, 24, 0, 33, "Text"],
Cell[13029, 430, 129, 3, 31, "Input"],
Cell[13161, 435, 90, 1, 30, "Input"],
Cell[13254, 438, 79, 1, 30, "Input"],
Cell[13336, 441, 44, 0, 33, "Text"],
Cell[13383, 443, 65, 1, 42, "Input"],
Cell[13451, 446, 38, 0, 33, "Text"],
Cell[13492, 448, 113, 2, 30, "Input"],
Cell[13608, 452, 73, 1, 30, "Input"],
Cell[13684, 455, 72, 1, 30, "Input"],
Cell[13759, 458, 72, 1, 30, "Input"],
Cell[13834, 461, 24, 0, 33, "Text"],
Cell[13861, 463, 75, 1, 30, "Input"],
Cell[13939, 466, 73, 1, 30, "Input"],
Cell[14015, 469, 64, 1, 30, "Input"],
Cell[14082, 472, 64, 1, 30, "Input"],
Cell[14149, 475, 31, 0, 33, "Text"],
Cell[14183, 477, 175, 3, 30, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

