(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     29435,       1054]*)
(*NotebookOutlinePosition[     30109,       1077]*)
(*  CellTagsIndexPosition[     30065,       1073]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["25. Jumps and shocks", "Title"],

Cell[BoxData[{
    \(<< Lautrup`\), "\[IndentingNewLine]", 
    \(<< Graphics`Spline`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics`\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stationary hydraulic jump", "Title"],

Cell[CellGroupData[{

Cell["Froude numbers", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Froude numbers before and after the jump", "Text"],

Cell[BoxData[{
    \(\(Fr = \@\(\((1 + \[Sigma])\) \((1 + \[Sigma]\/2)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(Frp = \@\(1 + \[Sigma]\/2\)\/\(1 + \[Sigma]\);\)\)}], "Input"],

Cell[BoxData[
    \(\(fig1a = 
        Plot[{Fr, Frp}, {\[Sigma], 0, 20}, 
          PlotRange \[Rule] {{0, 10}, {0, 8.5}}, AxesOrigin \[Rule] {0, 0}, 
          AxesLabel \[Rule] {"\<\[Sigma]\>", "\<\>"}, 
          PlotStyle \[Rule] {Text["\<Fr\>", {5, 5}, {\(-1\), \(-1\)}], 
              Text["\<Fr'\>", {5, 0.2}, {\(-1\), \(-1\)}]}, 
          PlotLabel -> "\<(a)\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1b = 
        Graphics[{Dashing[{0.02}], Line[{{0, 1}, {20, 1}}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, fig1b] // \[IndentingNewLine]Figure["\<jumps1\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Energy loss", "Section"],

Cell["Power in % of kinetic energy", "Text"],

Cell[BoxData[
    \(\(P = 
        100  \[Sigma]\^3\/\(\(\((1 + \[Sigma])\)\^2\) \((2 + \[Sigma])\)\);\)\
\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[{Fr, P}, {\[Sigma], 0, 20}, 
          PlotRange \[Rule] {{0, 14}, {0, 85}}, PlotLabel -> "\<(b)\>", 
          AxesLabel \[Rule] {"\<Fr\>", "\<%\>"}] \
// \[IndentingNewLine]Figure["\<jumps2\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot (see example 24.1.1)", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(Q = 100\ Centimeter\^3/Second // NToCGS;\)\), "\[IndentingNewLine]", 
    \(\(a = 0.5\ Centimeter // NToCGS;\)\), "\[IndentingNewLine]", 
    \(\(R = 7\ Centimeter // NToCGS;\)\), "\[IndentingNewLine]", 
    \(\(A = 12\ Centimeter // NToCGS;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = 
        0.86\ 10\^\(-2\)\ Centimeter\^2/Second // 
          NToCGS;\)\), "\[IndentingNewLine]", 
    \(\(h = 0.17857\ Millimeter // NToCGS;\)\), "\[IndentingNewLine]", 
    \(\(h' = 7.5944\ Millimeter // NToCGS;\)\)}], "Input"],

Cell["Average velocity at start", "Text"],

Cell[BoxData[
    \(\(U = Q\/\(\[Pi]\ a\^2\);\)\)], "Input"],

Cell[BoxData[
    \(\(fig1a = Plot[Q\/\(2  \[Pi]\ r\ U\), {r, a, R}];\)\)], "Input"],

Cell["Boundary layer thickness before the jump", "Text"],

Cell[BoxData[
    \(\(\[Delta] = 3 \@\(\( \[Nu]\ \ \((r - a)\)\)\/U\);\)\)], "Input"],

Cell[BoxData[
    \(\(fig1b = 
        Plot[\ \[Delta], {r, a, R}, 
          PlotStyle \[Rule] Dashing[{0.01, 0.01}]];\)\)], "Input"],

Cell["Critical wave length", "Text"],

Cell[BoxData[
    \(\[Lambda]\_0 = 4  \[Pi]\ h\)], "Input"],

Cell["Velocity after the jump", "Text"],

Cell[BoxData[
    \(\(U' = Q\/\(2  \[Pi]\ r\ h'\);\)\)], "Input"],

Cell[BoxData[
    \(\(\[Delta] = 
        3 \@\(\( \[Nu]\ \((R - a)\)\)\/U\) + 
          3 \@\(\( \[Nu]\ \((r - R)\)\)\/U'\);\)\)], "Input"],

Cell[BoxData[
    \(\(fig1c = 
        Plot[\[Delta], {r, R, A}, 
          PlotStyle \[Rule] Dashing[{0.01, 0.01}]];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1d = 
        Graphics[{Spline[{{R, h}, {R, h'}, {R + \[Lambda]\_0, 
                  h'}, {R + 2  \[Lambda]\_0, h'}, {A, h'}}, 
              Bezier]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, fig1b, fig1c, fig1d, 
          Graphics[{Text["\<R\>", {7, \(-0.02\)}, {0, 1}], 
              Text["\<a\>", {0.5, \(-0.02\)}, {0, 1}]}], 
          AxesLabel \[Rule] {"\<r[cm]\>", "\<h[cm]\>"}, 
          AspectRatio \[Rule] 0.33, PlotRange \[Rule] {\(-0.11\), 1}, 
          ImageSize \[Rule] 
            500] // \[IndentingNewLine]Figure["\<jumps5\>"];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Moving hydraulic jump", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(Solve[\@\(\((1 + \[Sigma])\) \((1 + \(1\/2\) \[Sigma])\)\) - \@\(\(1 + \
\(1\/2\) \[Sigma]\)\/\(1 + \[Sigma]\)\) == \@\(1 + \[Sigma]\), \[Sigma]] // 
      N\)], "Input"],

Cell[BoxData[
    \(\(Plot[{\@\(\((1 + \[Sigma])\) \((1 + \(1\/2\) \[Sigma])\)\) - \@\(\(1 \
+ \(1\/2\) \[Sigma]\)\/\(1 + \[Sigma]\)\), \@\(1 + \[Sigma]\)}, {\[Sigma], 0, 
          10}];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Critical wavelength", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Group velocity after the jump", "Text"],

Cell[BoxData[
    \(\(cp[
          k_] = \(\@\(Tanh[
                    k]\/k\)\) \(1\/2\) \((1 + \(2  k\)\/Sinh[2  k])\);\)\)], \
"Input"],

Cell["Froude number before the jump", "Text"],

Cell[BoxData[
    \(\(Fr[\[Sigma]_] = \@\(\((1 + \[Sigma])\) \((1 + \(1\/2\) \[Sigma])\)\);\
\)\)], "Input"],

Cell["Froude number after the jump", "Text"],

Cell[BoxData[
    \(\(Frp[\[Sigma]_] = \@\(1 + \(1\/2\) \[Sigma]\)\/\(1 + \[Sigma]\);\)\)], \
"Input"],

Cell["Solution", "Text"],

Cell[BoxData[
    \(\[Psi][\[Sigma]_?NumericQ] := 
      k /. FindRoot[cp[k] \[Equal] Frp[\[Sigma]], {k, 1.1, 1.2}]\)], "Input"],

Cell[BoxData[
    \(\(Plot[\[Psi][\[Sigma]], {\[Sigma], 0, 10}, 
          AxesLabel \[Rule] {"\<\[Sigma]\>", "\<\[Psi]\>"}, 
          PlotRange \[Rule] All] // \[IndentingNewLine]Figure["\<jumps3\>", 
          ImageSize \[Rule] 250];\)\)], "Input"],

Cell["Cutoff parameter", "Text"],

Cell[BoxData[
    \(\(\[Epsilon] = 0.05;\)\)], "Input"],

Cell["Make an interpolation (to save time)", "Text"],

Cell[BoxData[
    \(\[Psi]int = 
      FunctionInterpolation[\[Psi][\[Sigma]], {\[Sigma], \[Epsilon], 20}, 
        InterpolationPoints \[Rule] 30, MaxRecursion \[Rule] 10]\)], "Input"],

Cell[BoxData[
    \(\(Plot[\[Psi]int[\[Sigma]] - \[Psi][\[Sigma]], {\[Sigma], \[Epsilon], 
          20}, PlotRange \[Rule] All];\)\)], "Input"],

Cell["Critical wave length", "Text"],

Cell[BoxData[
    \(\(\[Lambda][\[Sigma]_?
            NumericQ] = \(\(2  \[Pi]\)\/\[Psi][\[Sigma]]\) \((1 + \
\[Sigma])\);\)\)], "Input"],

Cell[BoxData[
    \(\(figa = 
        ParametricPlot[{Fr[\[Sigma]], \[Lambda][\[Sigma]]}, {\[Sigma], \
\[Epsilon], 20}, PlotRange \[Rule] {{0, 14}, {10, 15}}, 
          PlotLabel -> "\<(b)\>", 
          AxesLabel \[Rule] {"\<Fr\>", \*"\"\<\!\(\[Lambda]\_0\/h\)\>\""}];\)\
\)], "Input"],

Cell[BoxData[
    \(\(figb = 
        Graphics[{Dashing[{0.02}], 
            Line[{{0, 4  \[Pi]}, {14, 4  \[Pi]}}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[figa, figb] // \[IndentingNewLine]Figure["\<jumps4\>", 
          ImageSize \[Rule] 250];\)\)], "Input"],

Cell["Minimum of curve", "Text"],

Cell[BoxData[
    \(Fr[\[Sigma]] /. 
      FindRoot[\(\[Lambda]'\)[\[Sigma]\ ], {\[Sigma], 1}]\)], "Input"],

Cell["Maximum of curve", "Text"],

Cell[BoxData[
    \(Fr[\[Sigma]] /. 
      FindRoot[\(\[Lambda]'\)[\[Sigma]\ ], {\[Sigma], 5}]\)], "Input"],

Cell["Values at minimum", "Text"],

Cell[BoxData[
    \({Fr[\[Sigma]], \[Lambda][\[Sigma]]} /. \(FindMaximum[\(\[Lambda]'\)[\
\[Sigma]], {\[Sigma], 1.8, 2.1}]\)[\([2]\)]\)], "Input"],

Cell["Turning points", "Text"],

Cell[BoxData[
    \(Fr[\[Sigma]] /. 
      FindRoot[\(\[Lambda]''\)[\[Sigma]], {\[Sigma], 2, 6}]\)], "Input"],

Cell[BoxData[
    \(Fr[\[Sigma]] /. 
      FindRoot[\(\[Lambda]''\)[\[Sigma]], {\[Sigma], 7, 10}]\)], "Input"],

Cell["Special values for use in example 24.2.1", "Text"],

Cell[BoxData[
    \(\[Psi][2]\)], "Input"],

Cell[BoxData[
    \(\[Lambda][2]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normal shocks", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameter", "Text"],

Cell[BoxData[
    \(\(\[Gamma] = 7/5;\)\)], "Input"],

Cell["Ratios of various quantities", "Text"],

Cell[BoxData[{
    \(\(Rp = 1 + \[Sigma];\)\), "\[IndentingNewLine]", 
    \(\(R\[Rho] = \(2  \[Gamma] + \((\[Gamma] + 1)\) \[Sigma]\)\/\(2  \
\[Gamma] + \((\[Gamma] - 1)\) \[Sigma]\);\)\), "\[IndentingNewLine]", 
    \(\(RU = 1\/R\[Rho];\)\), "\[IndentingNewLine]", 
    \(\(RT = Rp\/R\[Rho];\)\), "\[IndentingNewLine]", 
    \(\(Ma = \@\(1 + \(\(\[Gamma] + 1\)\/\(2  \[Gamma]\)\) \[Sigma]\);\)\), "\
\[IndentingNewLine]", 
    \(\(MaP = \@\(1 - \(\(\[Gamma] + 1\)\/\(2  \[Gamma]\)\) \[Sigma]\/\(\
\[Sigma] + 1\)\);\)\), "\[IndentingNewLine]", 
    \(\(Rs = Log[Rp\ R\[Rho]\^\(-\[Gamma]\)];\)\)}], "Input"],

Cell[BoxData[
    \(\(Plot[{Rp, R\[Rho], RT, Ma, MaP, Rs}, {\[Sigma], 0, 40}, 
        PlotRange \[Rule] {{0, 40}, {0, 10}}, 
        AxesLabel \[Rule] {"\<\[Sigma]\>", "\<\>"}, 
        PlotStyle \[Rule] {{Dashing[{}], 
              Text["\<p'/p\>", {4.3, 7}]}, {Dashing[{}], 
              Text["\<\[Rho]'/\[Rho]\>", {35, 4.7}]}, {Dashing[{}], 
              Text["\<T'/T\>", {35, 7.5}]}, {Dashing[{0.02}], 
              Text["\<Ma\>", {35, 6}]}, {Dashing[{0.02}], 
              Text["\<Ma'\>", {35, 0.7}]}, {Dashing[{0.003, 0.01}], 
              Text[\*"\"\<\[CapitalDelta]s/\!\(c\_V\)\>\"", {35, 
                  1.8}]}}];\)\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[{{Ma, Rp}, {Ma, R\[Rho]}, {Ma, RT}, {Ma, MaP}, {Ma, 
              Rs}}, {\[Sigma], 0, 200}, PlotRange \[Rule] {{1, 10}, {0, 15}}, 
          AxesLabel \[Rule] {"\<Ma\>", "\<\>"}, AxesOrigin \[Rule] {1, 0}, 
          PlotStyle \[Rule] {{Dashing[{}], 
                Text["\<p'/p\>", {2, 7}]}, {Dashing[{}], 
                Text["\<\[Rho]'/\[Rho]\>", {8, 6}]}, {Dashing[{}], 
                Text["\<T'/T\>", {5.1, 7}]}, {Dashing[{0.02}], 
                Text["\<Ma'\>", {8, 0.7}]}, {Dashing[{0.003, 0.01}], 
                Text[\*"\"\<\[CapitalDelta]s/\!\(c\_V\)\>\"", {8, 
                    2.3}]}}] \
// \[IndentingNewLine]Figure["\<jumps6\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Shock thickness", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(\[Nu] = 1.5*^-5\ Meter\^2/Second;\)\), "\[IndentingNewLine]", 
    \(\(c = 343\ Meter/Second;\)\)}], "Input"],

Cell["Thickness", "Text"],

Cell[BoxData[
    \(\[Delta] = \[Nu]\/c // ToUnit[Nanometer]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Strong radial shock wave", "Title"],

Cell[CellGroupData[{

Cell["Test", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\((\(2  \[Sigma]\)\/\(2  \[Gamma] + \((\[Gamma] + 1)\) \[Sigma]\))\)\^2 \
+ \(4\/\(\[Gamma] - 
                1\)\) \[Sigma]\/\(2  \[Gamma] + \((\[Gamma] + 1)\) \[Sigma]\) \
- \(\(4  \[Gamma]\)\/\(\[Gamma] - 
                1\)\) \(\(1 + \[Sigma]\)\/\(2  \[Gamma] + \((\[Gamma] + 
                      1)\) \[Sigma]\)\) \(2  \[Sigma]\)\/\(2  \[Gamma] + \((\
\[Gamma] + 1)\) \[Sigma]\) // Simplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Trinity blast (Taylor data)", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Time values in milliseconds", "Text"],

Cell[BoxData[
    \(\(ts = {0.10, 0.24, 0.38, 0.52, 0.66, 0.80, 0.94, 1.08, 1.22, 1.36, 
          1.50, 1.65, 1.79, 1.93, 3.26, 3.53, 3.80, 4.07, 4.34, 4.61, 15.0, 
          25.0, 34.0, 53.0, 62.0};\)\)], "Input"],

Cell["Radius values in meter", "Text"],

Cell[BoxData[
    \(\(Rs = {11.1, 19.9, 25.4, 28.8, 31.9, 34.2, 36.3, 38.9, 41.0, 42.8, 
          44.4, 46.0, 46.9, 48.7, 59.0, 61.1, 62.9, 64.3, 65.6, 67.3, 106.5, 
          130.0, 145.0, 175.0, 185.0};\)\)], "Input"],

Cell["Data should be constant if the 2/5 rule holds", "Text"],

Cell[BoxData[
    \(data = 5  Log[10, Rs] - 2\ Log[10, ts]\)], "Input"],

Cell["Take mean value for 0.4<t<5", "Text"],

Cell[BoxData[
    \(GI = Mean[Take[data, {4, \(-5\)}]]\)], "Input"],

Cell["Show the data", "Text"],

Cell[BoxData[
    \(\(LogLinearListPlot[Thread[{ts, data}], 
        PlotRange \[Rule] All];\)\)], "Input"],

Cell["Density of air", "Text"],

Cell[BoxData[
    \(\(\[Rho]\_0 = 1.2\ Kilogram/Meter\^3;\)\)], "Input"],

Cell["Yield of Trinity", "Text"],

Cell[BoxData[
    \(E\_0 = \(\[Rho]\_0\) \(10\^GI\) 
          Meter\^5\/\(\(\ \)\(\((Milli\ Second)\)\^2\)\) // 
        ToUnit[Joule]\)], "Input"],

Cell["TNT burn value", "Text"],

Cell[BoxData[
    \(\(TNT\  = 5\ Mega\ Joule/Kilogram;\)\)], "Input"],

Cell["Yield in units of TNT", "Text"],

Cell[BoxData[
    \(E\_0\/\(\(\ \)\(TNT\)\) // ToUnit[Kilo\ MetricTon]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Self-similar shape", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Substitution", "Text"],

Cell[BoxData[
    \(\(do[x_] := x /. \[Xi] \[Rule] r\/R[t];\)\)], "Input"],

Cell["Assumptions of form", "Text"],

Cell[BoxData[{
    \(\(v\_r = \ \(R'\)[t] u[\[Xi]] // do;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho] = \(\[Rho]\_0\) f[\[Xi]] // do;\)\), "\[IndentingNewLine]", 
    \(\(p = \(\[Rho]\_0\) \(\(R'\)[t]\^2\) q[\[Xi]] // 
          do;\)\), "\[IndentingNewLine]", 
    \(\(S = \(\(R'\)[t]\^2\) s[\[Xi]] // do;\)\)}], "Input"],

Cell["Differential equations (all left hand sides vanish)", "Text"],

Cell[BoxData[{
    \(\(zero1 = \[PartialD]\_t v\_r + \(v\_r\) \[PartialD]\_r v\_r + \(1\/\
\[Rho]\) \[PartialD]\_r p;\)\), "\[IndentingNewLine]", 
    \(\(zero2 = \[PartialD]\_t \[Rho] + \(v\_r\) \[PartialD]\_r \[Rho] + \
\[Rho]\ \[PartialD]\_r v\_r + 
          2\ \(\[Rho]\ v\_r\)\/r;\)\), "\[IndentingNewLine]", 
    \(\(zero3 = \[PartialD]\_t S + \(v\_r\) \[PartialD]\_r S;\)\)}], "Input"],

Cell["Substitute back", "Text"],

Cell[BoxData[
    \(\(do[x_] := x /. r \[Rule] \[Xi]\ R[t] // Expand;\)\)], "Input"],

Cell["Simplify differential equations", "Text"],

Cell[BoxData[
    \(zero1a = zero1\ \(R[t]/\(R'\)[t]\^2\)/u[\[Xi]] // do\)], "Input"],

Cell[BoxData[
    \(zero2a = 
      zero2\ \(\(R[t]/\(R'\)[t]\)/\[Rho]\_0\)/f[\[Xi]] // do\)], "Input"],

Cell[BoxData[
    \(zero3a = zero3\ \(R[t]/\(R'\)[t]\^3\)/s[\[Xi]] // do\)], "Input"],

Cell["The form of the radial expansion", "Text"],

Cell[BoxData[
    \(\(R[t_] = \ K\ t\^\(1/\((1 - \[Alpha])\)\);\)\)], "Input"],

Cell["Simplify more to get the final equations", "Text"],

Cell[BoxData[
    \(zero1b = zero1a\ u[\[Xi]] // Simplify\)], "Input"],

Cell[BoxData[
    \(zero2b = zero2a\ f[\[Xi]] // Simplify\)], "Input"],

Cell[BoxData[
    \(zero3b = \(zero3a // Simplify\) // Expand\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numeric solution", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\(\[Epsilon] = 10\^\(-3\);\)\)], "Input"],

Cell["Equations (the left hand sides must vanish)", "Text"],

Cell[BoxData[{
    \(\(eq1 = \(-\(3\/2\)\)\ u[\[Xi]] + \((u[\[Xi]] - \[Xi])\) \(u'\)[\[Xi]] \
+ \(q'\)[\[Xi]]\/f[\[Xi]];\)\), "\[IndentingNewLine]", 
    \(\(eq2 = \((u[\[Xi]] - \[Xi])\) \(f'\)[\[Xi]] + 
          f[\[Xi]]\ \(u'\)[\[Xi]] + \(2\ u[\[Xi]] f[\[Xi]]\)\/\[Xi];\)\), "\
\[IndentingNewLine]", 
    \(\(eq3[\[Gamma]_] = \(-3\) + \((u[\[Xi]] - \[Xi])\) \((\(q'\)[\[Xi]]\/q[\
\[Xi]] - \[Gamma]\ \(f'\)[\[Xi]]\/f[\[Xi]])\);\)\)}], "Input"],

Cell["Initial values", "Text"],

Cell[BoxData[{
    \(\(u1[\[Gamma]_] = 2\/\(\[Gamma] + 1\);\)\), "\[IndentingNewLine]", 
    \(\(f1[\[Gamma]_] = \(\[Gamma] + 1\)\/\(\[Gamma] - 1\);\)\), "\
\[IndentingNewLine]", 
    \(\(q1[\[Gamma]_] = 2\/\(\[Gamma] + 1\);\)\)}], "Input"],

Cell["Solve coupled differential equations", "Text"],

Cell[BoxData[
    \(sol[\[Gamma]_?
          NumericQ] := \(NDSolve[{eq1 \[Equal] 0, eq2 \[Equal] 0, 
            eq3[\[Gamma]] \[Equal] 0, u[1] \[Equal] u1[\[Gamma]], 
            f[1] \[Equal] f1[\[Gamma]], q[1] \[Equal] q1[\[Gamma]]}, {u, f, 
            q}, {\[Xi], 1, \[Epsilon]}]\)[\([1]\)]\)], "Input"],

Cell["Choice of \[Gamma]", "Text"],

Cell[BoxData[
    \(\(\[Gamma] = 7\/5;\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[
          Evaluate[{u[\[Xi]]\/u1[\[Gamma]], f[\[Xi]]\/f1[\[Gamma]], 
                q[\[Xi]]\/q1[\[Gamma]]} /. 
              sol[\[Gamma]]], {\[Xi], \[Epsilon], 1}, 
          PlotRange \[Rule] {0, 1}, 
          PlotStyle \[Rule] {{Dashing[{}], 
                Text[\*"\"\<u/\!\(u\_1\)\>\"", {0.8, 
                    0.75}, {0, \(-1\)}]}, {Dashing[{0.01}], 
                Text[\*"\"\<q/\!\(q\_1\)\>\"", {0.2, 
                    0.4}, {0, \(-1\)}]}, {Dashing[{0.02}], 
                Text[\*"\"\<f/\!\(f\_1\)\>\"", {0.8, 0.1}, {0, \(-1\)}]}}, 
          AxesLabel \[Rule] {"\<\[Xi]\>", "\<\>"}] \
// \[IndentingNewLine]Figure["\<jumps7\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Excess energy", "Section"],

Cell["Integration constant", "Text"],

Cell[BoxData[
    \(K[\[Gamma]_] := 
      4  \[Pi]\ NIntegrate[
          Evaluate[\((\(1\/2\) f[\[Xi]] u[\[Xi]]\^2 + 
                    q[\[Xi]]\/\(\[Gamma] - 1\))\) \[Xi]\^2 /. 
              sol[\[Gamma]]], {\[Xi], \[Epsilon], 1}]\)], "Input"],

Cell["Constant in Taylor's relation", "Text"],

Cell[BoxData[
    \(A[\[Gamma]_] := \((\(4\/25\) K[\[Gamma]])\)\^\(\(-1\)/5\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[A[\[Gamma]], {\[Gamma], 1, 2}, 
          AxesLabel \[Rule] {"\<\[Gamma]\>", "\<A\>"}, 
          PlotRange \[Rule] {{1, 2}, {0.65, 
                1.35}}] // \[IndentingNewLine]Figure["\<jumps8\>", 
          ImageSize \[Rule] 250];\)\)], "Input"],

Cell["Value of constant for air", "Text"],

Cell[BoxData[
    \(A[7/5]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Title"],

Cell[CellGroupData[{

Cell["24.1.1 Kitchen sink", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(Q = 100\ Centimeter\^3/Second;\)\), "\[IndentingNewLine]", 
    \(\(a = 0.5\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(R = 7\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(A = 12\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = 0.86\ 10\^\(-2\)\ Centimeter\^2/Second;\)\)}], "Input"],

Cell["Average velocity", "Text"],

Cell[BoxData[
    \(U = Q\/\(\[Pi]\ a\^2\) // N\)], "Input"],

Cell["Height before jump", "Text"],

Cell[BoxData[
    \(h = Q\/\(2  \[Pi]\ R\ U\) // ToUnit[Millimeter]\)], "Input"],

Cell["Shallow-wave velocity before jump", "Text"],

Cell[BoxData[
    \(c = \@\(\(g\_0\) h\) // ToUnit[Centimeter/Second]\)], "Input"],

Cell["Froude number before jump", "Text"],

Cell[BoxData[
    \(Fr = U\/c\)], "Input"],

Cell["Strength parameter", "Text"],

Cell[BoxData[
    \(\[Sigma] = \(\@2\) Fr\  - 3\/2\)], "Input"],

Cell["Height after jump", "Text"],

Cell[BoxData[
    \(h' = h \((1 + \[Sigma])\)\)], "Input"],

Cell["Velocity after jump", "Text"],

Cell[BoxData[
    \(U' = U\/\(1 + \[Sigma]\)\)], "Input"],

Cell["Froude number after jump", "Text"],

Cell[BoxData[
    \(Frp = Fr\/\((1 + \[Sigma])\)\^\(3/2\)\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds = \(U\ h\)\/\[Nu] // ToSI\)], "Input"],

Cell["Boundary layer thickness before jump", "Text"],

Cell[BoxData[
    \(\[Delta] = 3 \@\(\( \[Nu]\ \ R\)\/U\) // ToUnit[Millimeter]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["24.1.2 River bore", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(h = 0.5\ Meter;\)\), "\[IndentingNewLine]", 
    \(\(h' = 1.5\ Meter;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi][2] = 1.629739;\)\  (*\ 
      from\ calculation\ above\ *) \), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\)}], "Input"],

Cell[BoxData[
    \(\[Sigma] = h'\/h - 1\)], "Input"],

Cell[BoxData[
    \(Fr = \@\(\((1 + \[Sigma])\) \((1 + \(1\/2\) \[Sigma])\)\)\)], "Input"],

Cell[BoxData[
    \(c = \@\(\(g\_0\) h\) // ToSI\)], "Input"],

Cell[BoxData[
    \(U = c\ Fr\)], "Input"],

Cell[BoxData[
    \(U' = U\/\(1 + \[Sigma]\)\)], "Input"],

Cell[BoxData[
    \(U - U'\)], "Input"],

Cell[BoxData[
    \(\[Lambda]p = \(2  \[Pi]\)\/\[Psi][2]\)], "Input"],

Cell[BoxData[
    \(\[Lambda] = \[Lambda]p\ h'\/h\)], "Input"],

Cell[BoxData[
    \(\[Lambda]\ h\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["24.2.1 Mach angle", "Section"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(Ma = 2;\)\), "\[IndentingNewLine]", 
    \(\(h = 20. \ Kilometer;\)\)}], "Input"],

Cell["Mach angle", "Text"],

Cell[BoxData[
    \(\[Phi] = ArcSin[\ 1\/Ma]\)], "Input"],

Cell["Distance to aircraft", "Text"],

Cell[BoxData[
    \(d = h\ Cot[\[Phi]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["24.3.1 Trinity ", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(TNT\  = \ 5  Mega\ Joule/Kilogram;\)\), "\n", 
    \(\(E\_0 = 17. \ \ Kilo\ MetricTon\ TNT // ToUnit[Joule];\)\), "\n", 
    \(\(M\_mol = AirMolarMass;\)\), "\n", 
    \(\(R\_mol = MolarGasConstant;\)\), "\n", 
    \(\(T\_0 = 293\ Kelvin;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\n", 
    \(\(t = 15\ Milli\ Second;\)\), "\n", 
    \(\(p\_0 = 1\ Atmosphere;\)\), "\n", 
    \(\(\[Gamma] = 1.4;\)\), "\n", 
    \(\(A = 1;\)\)}], "Input"],

Cell["Air density", "Text"],

Cell[BoxData[
    \(\[Rho]\_0 = \(p\_0\/T\_0\) M\_mol\/R\_mol // ToSI\)], "Input"],

Cell["Sound velocity", "Text"],

Cell[BoxData[
    \(c\_0 = \@\(\(\[Gamma]\ p\_0\)\/\[Rho]\_0\) // ToSI\)], "Input"],

Cell["Radius of shock wave", "Text"],

Cell[BoxData[
    \(R = A \((\(E\_0\ t\^2\)\/\[Rho]\_0)\)\^\(1/5\) // ToSI\)], "Input"],

Cell["Velocity of shock front", "Text"],

Cell[BoxData[
    \(U = \(2\/5\) R\/t // ToSI\)], "Input"],

Cell["Strength of shock", "Text"],

Cell[BoxData[
    \(\[Sigma] = \(\(8 
                 A\^2\)\/\(25 \((\[Gamma] + 
                    1)\)\)\) \(\(\(E\_0\^\(2/
                      5\)\) \[Rho]\_0\^\(3/5\)\)\/p\_0\) t\^\(\(-6\)/5\) // 
        ToSI\)], "Input"],

Cell["Pressure just inside front", "Text"],

Cell[BoxData[
    \(p\_1 = \(2\/\(\[Gamma] + 1\)\) \(\[Rho]\_0\) U\^2 // 
        ToUnit[Atmosphere]\)], "Input"],

Cell["Density just inside front", "Text"],

Cell[BoxData[
    \(\[Rho]\_1 = \(\(\[Gamma] + 1\)\/\(\[Gamma] - 1\)\) \[Rho]\_0\)], "Input"],

Cell["Temperature just inside front", "Text"],

Cell[BoxData[
    \(T\_1 = \ \(\(2 \((\[Gamma] - 
                    1)\)\)\/\((\[Gamma] + 1)\)\^2\) \(\(M\_mol\) \
U\^2\)\/R\_mol // ToSI\)], "Input"],

Cell["Check with Taylor's calculation", "Text"],

Cell[BoxData[
    \(p\_1\/g\_0 // ToUnit[Ton/Inch\^2]\)], "Input"],

Cell[CellGroupData[{

Cell["Strong limit time", "Subsection"],

Cell[BoxData[
    \(\(p\_s = 8\ p\_0;\)\)], "Input"],

Cell[BoxData[
    \(U\_s = U \@\( p\_s\/p\_1\) // ToSI\)], "Input"],

Cell[BoxData[
    \(t\_s = t \((U\_s\/U)\)\^\(\(-5\)/3\) // ToSI\)], "Input"],

Cell[BoxData[
    \(R\_s = R \((t\_s\/t)\)\^\(2/5\) // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Core expansion stop", "Subsection"],

Cell[BoxData[
    \(\(q\_0 = 0.3045;\)\)], "Input"],

Cell[BoxData[
    \(U\_c = \@\(p\_0\/\(\(\[Rho]\_0\) q\_0\)\) // ToSI\)], "Input"],

Cell[BoxData[
    \(t\_c = 
      t \((U\_c\/U)\)\^\(\(-5\)/3\) // ToUnit[Milli\ Second]\)], "Input"],

Cell[BoxData[
    \(R\_c = R \((t\_c\/t)\)\^\(2/5\) // ToSI\)], "Input"],

Cell[BoxData[
    \(0.7  R\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Title"],

Cell[CellGroupData[{

Cell["24.3 Solving Rankine-Hugoniot", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\(eqs = {\[Rho]\ U \[Equal] \[Rho]'\ U', \[Rho]\ U\^2 + 
              p \[Equal] \[Rho]' U'\^2 + p', 
          U\^2 + \(\(2  \[Gamma]\)\/\(\[Gamma] - 1\)\) p\/\[Rho]\  \[Equal] 
            U'\^2 + \(\(2  \[Gamma]\)\/\(\[Gamma] - 1\)\) 
                p'\/\(\(\[Rho]'\)\(\[IndentingNewLine]\)
                  \)};\)\)], "Input"],

Cell[BoxData[
    \(sol = Solve[eqs, {U', \[Rho]', p'}] // Simplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["24.4 Hugoniot's relation", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\(\(\[CapitalDelta]u = \(1\/2\) \(\[Rho]'\/\[Rho]\) \(p' - \
p\)\/\(\[Rho]' - \[Rho]\) - \(1\/2\) \(\[Rho]\/\[Rho]'\) \(p' - \
p\)\/\(\[Rho]' - \[Rho]\) + p\/\[Rho] - p'\/\[Rho]' // 
        Simplify\)\(\[IndentingNewLine]\)
    \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["24.5 Derivative of entropy", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_\[Sigma] 
          Log[\((1 + \[Sigma])\) \((\(2  \[Gamma] + \((\[Gamma] - 1)\) \
\[Sigma]\)\/\(2  \[Gamma] + \((\[Gamma] + 1)\) \[Sigma]\))\)\^\[Gamma]] // 
      Simplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["24.6 Hydrogen bomb", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(TNT\  = \ 5  Mega\ Joule/Kilogram;\)\), "\n", 
    \(\(E\_0 = 50. \ Mega\ MetricTon\ TNT // ToUnit[Joule];\)\), "\n", 
    \(\(M\_mol = AirMolarMass;\)\), "\n", 
    \(\(R\_mol = MolarGasConstant;\)\), "\n", 
    \(\(T\_0 = 293\ Kelvin;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\n", 
    \(\(t = 1\ Second;\)\), "\n", 
    \(\(p\_0 = 1\ Atmosphere;\)\), "\n", 
    \(\(\[Gamma] = 1.4;\)\), "\n", 
    \(\(A = 1;\)\)}], "Input"],

Cell["Yield", "Text"],

Cell[BoxData[
    \(E\_0 // ToUnit[Joule]\)], "Input"],

Cell["Air density", "Text"],

Cell[BoxData[
    \(\[Rho]\_0 = \(p\_0\/T\_0\) M\_mol\/R\_mol // ToSI\)], "Input"],

Cell["Sound velocity", "Text"],

Cell[BoxData[
    \(c\_0 = \@\(\(\[Gamma]\ p\_0\)\/\[Rho]\_0\) // ToSI\)], "Input"],

Cell["Radius of shock wave", "Text"],

Cell[BoxData[
    \(R = A \((\(E\_0\ t\^2\)\/\[Rho]\_0)\)\^\(1/5\) // ToSI\)], "Input"],

Cell["Velocity of shock front", "Text"],

Cell[BoxData[
    \(U = \(2\/5\) R\/t // ToSI\)], "Input"],

Cell["Strength of shock", "Text"],

Cell[BoxData[
    \(\[Sigma] = \(\(8 
                 A\^2\)\/\(25 \((\[Gamma] + 
                    1)\)\)\) \(\(\(E\_0\^\(2/
                      5\)\) \[Rho]\_0\^\(3/5\)\)\/p\_0\) t\^\(\(-6\)/5\) // 
        ToSI\)], "Input"],

Cell["Pressure just inside front", "Text"],

Cell[BoxData[
    \(p\_1 = \(2\/\(\[Gamma] + 1\)\) \(\[Rho]\_0\) U\^2 // 
        ToUnit[Atmosphere]\)], "Input"],

Cell["Density just inside front", "Text"],

Cell[BoxData[
    \(\[Rho]\_1 = \(\(\[Gamma] + 1\)\/\(\[Gamma] - 1\)\) \[Rho]\_0\)], "Input"],

Cell["Temperature just inside front", "Text"],

Cell[BoxData[
    \(T\_1 = \ \(\(2 \((\[Gamma] - 
                    1)\)\)\/\((\[Gamma] + 1)\)\^2\) \(\(M\_mol\) \
U\^2\)\/R\_mol // ToSI\)], "Input"],

Cell["Check with Taylor's calculation", "Text"],

Cell[BoxData[
    \(p\_1\/g\_0 // ToUnit[Ton/Inch\^2]\)], "Input"],

Cell[CellGroupData[{

Cell["Strong limit time", "Subsection"],

Cell[BoxData[
    \(\(p\_s = 8\ p\_0;\)\)], "Input"],

Cell[BoxData[
    \(U\_s = U \@\( p\_s\/p\_1\) // ToSI\)], "Input"],

Cell[BoxData[
    \(t\_s = t \((U\_s\/U)\)\^\(\(-5\)/3\) // ToSI\)], "Input"],

Cell[BoxData[
    \(R\_s = R \((t\_s\/t)\)\^\(2/5\) // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Core expansion stop", "Subsection"],

Cell[BoxData[
    \(\(q\_0 = 0.3045;\)\)], "Input"],

Cell[BoxData[
    \(U\_c = \@\(p\_0\/\(\(\[Rho]\_0\) q\_0\)\) // ToSI\)], "Input"],

Cell[BoxData[
    \(t\_c = 
      t \((U\_c\/U)\)\^\(\(-5\)/3\) // ToUnit[Milli\ Second]\)], "Input"],

Cell[BoxData[
    \(R\_c = R \((t\_c\/t)\)\^\(2/5\) // ToSI\)], "Input"],

Cell[BoxData[
    \(0.7  R\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
AutoGeneratedPackage->None,
WindowSize->{754, 740},
WindowMargins->{{Automatic, 228}, {45, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 95, "Title"],
Cell[1816, 55, 182, 4, 70, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[2035, 64, 42, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[2102, 68, 33, 0, 73, "Section"],
Cell[2138, 70, 46, 1, 30, "Input"],
Cell[2187, 73, 56, 0, 33, "Text"],
Cell[2246, 75, 177, 3, 98, "Input"],
Cell[2426, 80, 389, 7, 90, "Input"],
Cell[2818, 89, 107, 2, 30, "Input"],
Cell[2928, 93, 133, 2, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3098, 100, 30, 0, 73, "Section"],
Cell[3131, 102, 44, 0, 33, "Text"],
Cell[3178, 104, 119, 3, 47, "Input"],
Cell[3300, 109, 282, 5, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3619, 119, 44, 0, 73, "Section"],
Cell[3666, 121, 46, 1, 30, "Input"],
Cell[3715, 124, 26, 0, 33, "Text"],
Cell[3744, 126, 539, 9, 150, "Input"],
Cell[4286, 137, 41, 0, 33, "Text"],
Cell[4330, 139, 60, 1, 43, "Input"],
Cell[4393, 142, 84, 1, 43, "Input"],
Cell[4480, 145, 56, 0, 33, "Text"],
Cell[4539, 147, 85, 1, 51, "Input"],
Cell[4627, 150, 134, 3, 30, "Input"],
Cell[4764, 155, 36, 0, 33, "Text"],
Cell[4803, 157, 59, 1, 30, "Input"],
Cell[4865, 160, 39, 0, 33, "Text"],
Cell[4907, 162, 65, 1, 43, "Input"],
Cell[4975, 165, 141, 3, 51, "Input"],
Cell[5119, 170, 132, 3, 30, "Input"],
Cell[5254, 175, 194, 4, 30, "Input"],
Cell[5451, 181, 406, 7, 110, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5906, 194, 38, 0, 95, "Title"],
Cell[5947, 196, 46, 1, 30, "Input"],
Cell[5996, 199, 190, 3, 63, "Input"],
Cell[6189, 204, 202, 3, 63, "Input"],

Cell[CellGroupData[{
Cell[6416, 211, 38, 0, 73, "Section"],
Cell[6457, 213, 46, 1, 30, "Input"],
Cell[6506, 216, 45, 0, 33, "Text"],
Cell[6554, 218, 141, 4, 51, "Input"],
Cell[6698, 224, 45, 0, 33, "Text"],
Cell[6746, 226, 108, 2, 51, "Input"],
Cell[6857, 230, 44, 0, 33, "Text"],
Cell[6904, 232, 102, 2, 67, "Input"],
Cell[7009, 236, 24, 0, 33, "Text"],
Cell[7036, 238, 128, 2, 30, "Input"],
Cell[7167, 242, 251, 4, 50, "Input"],
Cell[7421, 248, 32, 0, 33, "Text"],
Cell[7456, 250, 55, 1, 30, "Input"],
Cell[7514, 253, 52, 0, 33, "Text"],
Cell[7569, 255, 185, 3, 30, "Input"],
Cell[7757, 260, 144, 2, 30, "Input"],
Cell[7904, 264, 36, 0, 33, "Text"],
Cell[7943, 266, 138, 3, 44, "Input"],
Cell[8084, 271, 287, 6, 64, "Input"],
Cell[8374, 279, 133, 3, 30, "Input"],
Cell[8510, 284, 131, 2, 50, "Input"],
Cell[8644, 288, 32, 0, 33, "Text"],
Cell[8679, 290, 107, 2, 30, "Input"],
Cell[8789, 294, 32, 0, 33, "Text"],
Cell[8824, 296, 107, 2, 30, "Input"],
Cell[8934, 300, 33, 0, 33, "Text"],
Cell[8970, 302, 146, 2, 30, "Input"],
Cell[9119, 306, 30, 0, 33, "Text"],
Cell[9152, 308, 109, 2, 30, "Input"],
Cell[9264, 312, 110, 2, 30, "Input"],
Cell[9377, 316, 56, 0, 33, "Text"],
Cell[9436, 318, 42, 1, 30, "Input"],
Cell[9481, 321, 45, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9575, 328, 30, 0, 95, "Title"],
Cell[9608, 330, 46, 1, 30, "Input"],
Cell[9657, 333, 25, 0, 33, "Text"],
Cell[9685, 335, 52, 1, 30, "Input"],
Cell[9740, 338, 44, 0, 33, "Text"],
Cell[9787, 340, 607, 10, 248, "Input"],
Cell[10397, 352, 647, 11, 130, "Input"],
Cell[11047, 365, 705, 11, 130, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11789, 381, 32, 0, 95, "Title"],
Cell[11824, 383, 46, 1, 30, "Input"],
Cell[11873, 386, 26, 0, 33, "Text"],
Cell[11902, 388, 132, 2, 50, "Input"],
Cell[12037, 392, 25, 0, 33, "Text"],
Cell[12065, 394, 73, 1, 40, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12175, 400, 41, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[12241, 404, 23, 0, 73, "Section"],
Cell[12267, 406, 46, 1, 30, "Input"],
Cell[12316, 409, 432, 7, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12785, 421, 46, 0, 73, "Section"],
Cell[12834, 423, 46, 1, 30, "Input"],
Cell[12883, 426, 43, 0, 33, "Text"],
Cell[12929, 428, 215, 3, 50, "Input"],
Cell[13147, 433, 38, 0, 33, "Text"],
Cell[13188, 435, 220, 3, 50, "Input"],
Cell[13411, 440, 61, 0, 33, "Text"],
Cell[13475, 442, 71, 1, 30, "Input"],
Cell[13549, 445, 43, 0, 33, "Text"],
Cell[13595, 447, 67, 1, 30, "Input"],
Cell[13665, 450, 29, 0, 33, "Text"],
Cell[13697, 452, 107, 2, 30, "Input"],
Cell[13807, 456, 30, 0, 33, "Text"],
Cell[13840, 458, 72, 1, 30, "Input"],
Cell[13915, 461, 32, 0, 33, "Text"],
Cell[13950, 463, 148, 3, 47, "Input"],
Cell[14101, 468, 30, 0, 33, "Text"],
Cell[14134, 470, 69, 1, 30, "Input"],
Cell[14206, 473, 37, 0, 33, "Text"],
Cell[14246, 475, 83, 1, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14366, 481, 37, 0, 73, "Section"],
Cell[14406, 483, 46, 1, 30, "Input"],
Cell[14455, 486, 28, 0, 33, "Text"],
Cell[14486, 488, 74, 1, 42, "Input"],
Cell[14563, 491, 35, 0, 33, "Text"],
Cell[14601, 493, 322, 5, 90, "Input"],
Cell[14926, 500, 67, 0, 33, "Text"],
Cell[14996, 502, 393, 6, 97, "Input"],
Cell[15392, 510, 31, 0, 33, "Text"],
Cell[15426, 512, 84, 1, 30, "Input"],
Cell[15513, 515, 47, 0, 33, "Text"],
Cell[15563, 517, 85, 1, 30, "Input"],
Cell[15651, 520, 103, 2, 30, "Input"],
Cell[15757, 524, 85, 1, 30, "Input"],
Cell[15845, 527, 48, 0, 33, "Text"],
Cell[15896, 529, 78, 1, 30, "Input"],
Cell[15977, 532, 56, 0, 33, "Text"],
Cell[16036, 534, 70, 1, 30, "Input"],
Cell[16109, 537, 70, 1, 30, "Input"],
Cell[16182, 540, 74, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16293, 546, 35, 0, 73, "Section"],
Cell[16331, 548, 46, 1, 30, "Input"],
Cell[16380, 551, 61, 1, 30, "Input"],
Cell[16444, 554, 59, 0, 33, "Text"],
Cell[16506, 556, 445, 7, 116, "Input"],
Cell[16954, 565, 30, 0, 33, "Text"],
Cell[16987, 567, 240, 4, 116, "Input"],
Cell[17230, 573, 52, 0, 33, "Text"],
Cell[17285, 575, 309, 5, 70, "Input"],
Cell[17597, 582, 34, 0, 33, "Text"],
Cell[17634, 584, 53, 1, 42, "Input"],
Cell[17690, 587, 727, 14, 126, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18454, 606, 32, 0, 73, "Section"],
Cell[18489, 608, 36, 0, 33, "Text"],
Cell[18528, 610, 249, 5, 44, "Input"],
Cell[18780, 617, 45, 0, 33, "Text"],
Cell[18828, 619, 90, 1, 43, "Input"],
Cell[18921, 622, 276, 5, 50, "Input"],
Cell[19200, 629, 41, 0, 33, "Text"],
Cell[19244, 631, 39, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19332, 638, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[19382, 642, 38, 0, 73, "Section"],
Cell[19423, 644, 46, 1, 30, "Input"],
Cell[19472, 647, 26, 0, 33, "Text"],
Cell[19501, 649, 395, 6, 130, "Input"],
Cell[19899, 657, 32, 0, 33, "Text"],
Cell[19934, 659, 60, 1, 43, "Input"],
Cell[19997, 662, 34, 0, 33, "Text"],
Cell[20034, 664, 80, 1, 43, "Input"],
Cell[20117, 667, 49, 0, 33, "Text"],
Cell[20169, 669, 82, 1, 32, "Input"],
Cell[20254, 672, 41, 0, 33, "Text"],
Cell[20298, 674, 42, 1, 42, "Input"],
Cell[20343, 677, 34, 0, 33, "Text"],
Cell[20380, 679, 63, 1, 42, "Input"],
Cell[20446, 682, 33, 0, 33, "Text"],
Cell[20482, 684, 58, 1, 30, "Input"],
Cell[20543, 687, 35, 0, 33, "Text"],
Cell[20581, 689, 57, 1, 42, "Input"],
Cell[20641, 692, 40, 0, 33, "Text"],
Cell[20684, 694, 70, 1, 44, "Input"],
Cell[20757, 697, 31, 0, 33, "Text"],
Cell[20791, 699, 67, 1, 42, "Input"],
Cell[20861, 702, 52, 0, 33, "Text"],
Cell[20916, 704, 92, 1, 51, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21045, 710, 36, 0, 73, "Section"],
Cell[21084, 712, 46, 1, 30, "Input"],
Cell[21133, 715, 280, 5, 90, "Input"],
Cell[21416, 722, 53, 1, 42, "Input"],
Cell[21472, 725, 90, 1, 51, "Input"],
Cell[21565, 728, 61, 1, 32, "Input"],
Cell[21629, 731, 42, 1, 30, "Input"],
Cell[21674, 734, 57, 1, 42, "Input"],
Cell[21734, 737, 39, 1, 30, "Input"],
Cell[21776, 740, 69, 1, 44, "Input"],
Cell[21848, 743, 62, 1, 42, "Input"],
Cell[21913, 746, 45, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21995, 752, 36, 0, 73, "Section"],
Cell[22034, 754, 26, 0, 33, "Text"],
Cell[22063, 756, 104, 2, 50, "Input"],
Cell[22170, 760, 26, 0, 33, "Text"],
Cell[22199, 762, 57, 1, 42, "Input"],
Cell[22259, 765, 36, 0, 33, "Text"],
Cell[22298, 767, 51, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22386, 773, 34, 0, 73, "Section"],
Cell[22423, 775, 46, 1, 30, "Input"],
Cell[22472, 778, 26, 0, 33, "Text"],
Cell[22501, 780, 495, 10, 210, "Input"],
Cell[22999, 792, 27, 0, 33, "Text"],
Cell[23029, 794, 82, 1, 44, "Input"],
Cell[23114, 797, 30, 0, 33, "Text"],
Cell[23147, 799, 83, 1, 51, "Input"],
Cell[23233, 802, 36, 0, 33, "Text"],
Cell[23272, 804, 87, 1, 48, "Input"],
Cell[23362, 807, 39, 0, 33, "Text"],
Cell[23404, 809, 58, 1, 42, "Input"],
Cell[23465, 812, 33, 0, 33, "Text"],
Cell[23501, 814, 231, 5, 47, "Input"],
Cell[23735, 821, 42, 0, 33, "Text"],
Cell[23780, 823, 113, 2, 44, "Input"],
Cell[23896, 827, 41, 0, 33, "Text"],
Cell[23940, 829, 93, 1, 44, "Input"],
Cell[24036, 832, 45, 0, 33, "Text"],
Cell[24084, 834, 152, 3, 47, "Input"],
Cell[24239, 839, 47, 0, 33, "Text"],
Cell[24289, 841, 66, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[24380, 846, 39, 0, 38, "Subsection"],
Cell[24422, 848, 52, 1, 30, "Input"],
Cell[24477, 851, 67, 1, 51, "Input"],
Cell[24547, 854, 77, 1, 43, "Input"],
Cell[24627, 857, 72, 1, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24736, 863, 41, 0, 38, "Subsection"],
Cell[24780, 865, 51, 1, 30, "Input"],
Cell[24834, 868, 82, 1, 51, "Input"],
Cell[24919, 871, 101, 2, 43, "Input"],
Cell[25023, 875, 72, 1, 43, "Input"],
Cell[25098, 878, 39, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25198, 886, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[25248, 890, 48, 0, 73, "Section"],
Cell[25299, 892, 46, 1, 30, "Input"],
Cell[25348, 895, 353, 6, 68, "Input"],
Cell[25704, 903, 80, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25821, 909, 43, 0, 73, "Section"],
Cell[25867, 911, 46, 1, 30, "Input"],
Cell[25916, 914, 264, 5, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26217, 924, 45, 0, 73, "Section"],
Cell[26265, 926, 46, 1, 30, "Input"],
Cell[26314, 929, 219, 4, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26570, 938, 37, 0, 73, "Section"],
Cell[26610, 940, 46, 1, 30, "Input"],
Cell[26659, 943, 26, 0, 33, "Text"],
Cell[26688, 945, 485, 10, 210, "Input"],
Cell[27176, 957, 21, 0, 33, "Text"],
Cell[27200, 959, 54, 1, 30, "Input"],
Cell[27257, 962, 27, 0, 33, "Text"],
Cell[27287, 964, 82, 1, 44, "Input"],
Cell[27372, 967, 30, 0, 33, "Text"],
Cell[27405, 969, 83, 1, 51, "Input"],
Cell[27491, 972, 36, 0, 33, "Text"],
Cell[27530, 974, 87, 1, 48, "Input"],
Cell[27620, 977, 39, 0, 33, "Text"],
Cell[27662, 979, 58, 1, 42, "Input"],
Cell[27723, 982, 33, 0, 33, "Text"],
Cell[27759, 984, 231, 5, 47, "Input"],
Cell[27993, 991, 42, 0, 33, "Text"],
Cell[28038, 993, 113, 2, 44, "Input"],
Cell[28154, 997, 41, 0, 33, "Text"],
Cell[28198, 999, 93, 1, 44, "Input"],
Cell[28294, 1002, 45, 0, 33, "Text"],
Cell[28342, 1004, 152, 3, 47, "Input"],
Cell[28497, 1009, 47, 0, 33, "Text"],
Cell[28547, 1011, 66, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[28638, 1016, 39, 0, 38, "Subsection"],
Cell[28680, 1018, 52, 1, 30, "Input"],
Cell[28735, 1021, 67, 1, 51, "Input"],
Cell[28805, 1024, 77, 1, 43, "Input"],
Cell[28885, 1027, 72, 1, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28994, 1033, 41, 0, 38, "Subsection"],
Cell[29038, 1035, 51, 1, 30, "Input"],
Cell[29092, 1038, 82, 1, 51, "Input"],
Cell[29177, 1041, 101, 2, 43, "Input"],
Cell[29281, 1045, 72, 1, 43, "Input"],
Cell[29356, 1048, 39, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

