(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19084,        719]*)
(*NotebookOutlinePosition[     19757,        742]*)
(*  CellTagsIndexPosition[     19713,        738]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["27. Lubrication", "Title"],

Cell[BoxData[
    \(<< Lautrup`\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Title"],

Cell[CellGroupData[{

Cell["27.1.1Playing card", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(M = 2\ Gram;\)\), "\[IndentingNewLine]", 
    \(\(L = 8\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(U = 1\ Meter/Second;\)\), "\[IndentingNewLine]", 
    \(\(f = 0.4;\)\), "\[IndentingNewLine]", 
    \(\(\[Eta] = 1.82*^-5\ Pascal\ Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho] = 1.2\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\)}], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Rey = \ \(\[Rho]\ U\ L\)\/\[Eta] // ToSI\)], "Input"],

Cell["Boundary layer thickness", "Text"],

Cell[BoxData[
    \(\[Delta] = L\/\@Rey // ToUnit[Millimeter]\)], "Input"],

Cell["Lift in balance with weight", "Text"],

Cell[BoxData[
    \(\(lift = \ M\ g\_0;\)\)], "Input"],

Cell["Area of card", "Text"],

Cell[BoxData[
    \(\(A = L\^2;\)\)], "Input"],

Cell["Skimming distance", "Text"],

Cell[BoxData[
    \(d = \@\(f\ \(\[Eta]\ U\ L\ A\)\/lift\) // ToUnit[Millimeter]\)], "Input"],

Cell["Angle of attack", "Text"],

Cell[BoxData[
    \(\[Alpha] = \(\(2\ d\)\/L\) f/Degree // ToSI\)], "Input"],

Cell["Lift to drag ratio", "Text"],

Cell[BoxData[
    \(f\ L\/d // ToSI\)], "Input"],

Cell["Flying height if lift==drag", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(\(\[Eta]\ U\ \ A\)\/\(\(lift\)\(\ \)\) // 
      ToUnit[Micrometer]\)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Harddisk ", "Section",
  FontSize->18],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell[BoxData[{
    \(\(L = 1\ Millimeter;\)\), "\[IndentingNewLine]", 
    \(\(R = 9/4\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalOmega] = 7000. \ RPM;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = 
        1.6\ \(10\^\(-5\)\) \(\(\ \)\(Meter\^2\)\)\/Second;\)\), "\
\[IndentingNewLine]", 
    \(\(\[Eta] = 
        1.8\ \(10\^\(-5\)\) Pascal\ Second;\)\), "\[IndentingNewLine]", 
    \(\(A = L\^2;\)\), "\[IndentingNewLine]", 
    \(\(d = 1\ Micrometer;\)\), "\[IndentingNewLine]", 
    \(\(h\_2 = 0.15\ Micrometer;\)\), "\[IndentingNewLine]", 
    \(\(f = 0.5;\)\)}], "Input",
  FontSize->14],

Cell[BoxData[
    \(U = R\ \[CapitalOmega] // ToSI\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(U // ToUnit[Kilometer/Hour]\)], "Input",
  FontSize->14],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds = \(U\ L\)\/\[Nu] // ToSI\)], "Input",
  FontSize->14],

Cell["Boundary layer thickness", "Text"],

Cell[BoxData[
    \(\[Delta] = L\/\@Reynolds // ToUnit[Micrometer]\)], "Input",
  FontSize->14],

Cell["Reynolds number in gap", "Text"],

Cell[BoxData[
    \(Reygap = \((d\/\[Delta])\)\^2\  // ToSI\)], "Input"],

Cell["Angle of attack in degrees", "Text"],

Cell[BoxData[
    \(\[Alpha] = 2 \( d - h\_2\)\/L // ToSI\)], "Input"],

Cell[BoxData[
    \(\[Alpha]/Degree\)], "Input"],

Cell["Geometry factor", "Text"],

Cell[BoxData[
    \(f = \[Alpha]\ L\/\(2  d\) // ToSI\)], "Input"],

Cell["Lift", "Text"],

Cell[BoxData[
    \(LL = f \( \[Eta]\ U\ L\ A\)\/d\^2 // ToUnit[Newton]\)], "Input",
  FontSize->14],

Cell["Average gap pressure", "Text"],

Cell[BoxData[
    \(\[CapitalDelta]p = LL\/A // ToUnit[Bar]\)], "Input",
  FontSize->14],

Cell["Form drag", "Text"],

Cell[BoxData[
    \(DF = \[Alpha]\ LL\)], "Input",
  FontSize->14],

Cell["Skin drag", "Text"],

Cell[BoxData[
    \(DS = \(\[Eta]\ U\ \ A\)\/d // ToUnit[Newton]\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(DF/DS\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(LL\/\(DS + DF\)\)], "Input",
  FontSize->14]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Flow reversal under Gaussian bump", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[CellGroupData[{

Cell["Theory", "Section"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(U = 1;\)\), "\[IndentingNewLine]", 
    \(\(Q = \(1\/2\) \(d\_0\) U;\)\)}], "Input"],

Cell["Velocities ", "Text"],

Cell[BoxData[{
    \(\(v\_x = 
        U \(\((h[x] - y)\) \((h[x] - 3  y)\)\)\/h[x]\^2 + 
          Q \( 6\ y \((h[x] - y)\)\)\/h[x]\^3;\)\), "\[IndentingNewLine]", 
    \(\(v\_y = \(-2\) \(h'\)[
            x] \(\(U\ h[x] - 3  Q\)\/h[x]\^4\) \(y\^2\) \((h[x] - 
              y)\);\)\)}], "Input"],

Cell["Stream function", "Text"],

Cell[BoxData[
    \(\(\[Psi][x_, 
          y_] = \(1\/h[x]\^2\) \(\((h[x] - y)\)\^2\) 
            y + \(d\_0\/\(2  h[x]\^3\)\) \(y\^2\) \((3  h[x] - 
                2  y)\);\)\)], "Input"],

Cell["Check that its derivatives are the velocities", "Text"],

Cell[BoxData[
    \(v\_x \[Equal] \[PartialD]\_y \[Psi][x, y] // Simplify\)], "Input"],

Cell[BoxData[
    \(v\_y == \(-\[PartialD]\_x \[Psi][x, y]\) // Simplify\)], "Input"],

Cell["Gaussian bump", "Text"],

Cell[BoxData[{
    \(\(a = 2;\)\), "\n", 
    \(\(L = 2  a;\)\), "\n", 
    \(\(b = 3;\)\)}], "Input"],

Cell[BoxData[
    \(\(h[x_] = 1 + b\ \[ExponentialE]\^\(-x\^2\);\)\)], "Input"],

Cell["Integrals", "Text"],

Cell[BoxData[
    \(h2 = NIntegrate[h[x]\^\(-2\), {x, \(-a\), a}]\)], "Input"],

Cell[BoxData[
    \(h3 = NIntegrate[h[x]\^\(-3\), {x, \(-a\), a}]\)], "Input"],

Cell["Effective gap width", "Text"],

Cell[BoxData[
    \(d\_0 = h2\/h3\)], "Input"],

Cell["Flow pattern", "Text"],

Cell[BoxData[
    \(\(fig3a = 
        ContourPlot[
          If[0 < y < h[x], \[Psi][x, y], 0], {x, \(-a\), a}, {y, 0, 1 + b}, 
          PlotPoints \[Rule] 200, Contours \[Rule] 10, 
          ContourShading \[Rule] False, Frame \[Rule] False];\)\)], "Input"],

Cell[BoxData[
    \(\(fig3b = 
        Graphics[{Thickness[0.01], Line[{{\(-a\), 0}, {a, 0}}], 
            Thickness[0.001], Dashing[{0.02}], 
            Line[{{\(-a\), d\_0}, {a, d\_0}}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(Show[fig3a, 
          fig3b] // \[IndentingNewLine]Figure["\<lubricate3\>"];\)\)\)], \
"Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Flat wing", "Title"],

Cell[CellGroupData[{

Cell["Integrals", "Section",
  FontSize->18],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input",
  FontSize->14],

Cell["Flat wing heights", "Text"],

Cell[BoxData[{
    \(\(h\_1 = d \((1 + \[Gamma])\);\)\), "\[IndentingNewLine]", 
    \(\(h\_2 = d \((1 - \[Gamma])\);\)\)}], "Input",
  FontSize->14],

Cell["Angle of attack", "Text"],

Cell[BoxData[
    \(\(\[Alpha]\  = \ \[Gamma]\ \(2  d\)\/L;\)\)], "Input",
  FontSize->14],

Cell["Shape of wing", "Text"],

Cell[BoxData[
    \(\(h = d - \[Alpha]\ x;\)\)], "Input"],

Cell["Effective gap width", "Text"],

Cell[BoxData[
    \(\(d\_0 = \((1 - \[Gamma]\^2)\) d;\)\)], "Input"],

Cell["Pressure", "Text"],

Cell[BoxData[
    \(p = \(3  \[Eta]\ U \((2  h - d\_0)\)\)\/\(\[Alpha]\ h\^2\) - \(3  \
\[Eta]\ U\)\/\(\[Alpha]\ d\) // Simplify\)], "Input"],

Cell["Lift", "Text"],

Cell[BoxData[
    \(\($Assumptions = \(-1\) < \[Gamma] < 1 && L > 0;\)\)], "Input"],

Cell[BoxData[
    \(LL = \(A\/L\) \(\[Integral]\_\(\(-L\)/2\)\%\(L/2\)p \[DifferentialD]x\) \
// Simplify\)], "Input",
  FontSize->14],

Cell["Shear stress on the ground", "Text"],

Cell[BoxData[
    \(\(\[Sigma] = \(-\[Eta]\)\ \ U \( 4  h - 3  d\_0\)\/h\^2;\)\)], "Input",
  FontSize->14],

Cell["Total drag on the wing", "Text"],

Cell[BoxData[
    \(DD = \(-\(A\/L\)\) \(\[Integral]\_\(\(-L\)/2\)\%\(L/2\)\[Sigma] \
\[DifferentialD]x\) // Simplify\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(Series[\(-\(\(3\ \[Gamma] + 2\ Log[1 - \[Gamma]] - 
              2\ Log[1 + \[Gamma]]\)\/\(\(\ \)\(\[Gamma]\)\)\)\), {\[Gamma], 
        0, 3}]\)], "Input"],

Cell[BoxData[
    \(MM = \(A\/L\) \(\[Integral]\_\(\(-L\)/2\)\%\(L/2\)x\ p\ \
\[DifferentialD]x\) // Simplify\)], "Input",
  FontSize->14],

Cell[BoxData[
    \(Series[\(3\ \((\(-6\)\ \[Gamma] + \((\(-3\) + \[Gamma]\^2)\)\ Log[1 - \
\[Gamma]] - \((\(-3\) + \[Gamma]\^2)\)\ Log[1 + \[Gamma]])\)\)\/\(8\ \[Gamma]\
\^3\), {\[Gamma], 0, 3}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Flat wing plots", "Section",
  FontSize->18],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Basic integrals", "Text"],

Cell[BoxData[{
    \(\(shape[\[Gamma]_] = 1 - \[Gamma]\^2;\)\), "\[IndentingNewLine]", 
    \(\(lift[\[Gamma]_] = \(3\/\(2  \[Gamma]\^2\)\) \((Log[\(1 + \[Gamma]\)\/\
\(1 - \[Gamma]\)] - 2  \[Gamma])\);\)\), "\[IndentingNewLine]", 
    \(\(drag[\[Gamma]_] = \(1\/\[Gamma]\) \((2 
                 Log[\(1 + \[Gamma]\)\/\(1 - \[Gamma]\)] - 
              3  \[Gamma])\);\)\), "\[IndentingNewLine]", 
    \(\(moment[\[Gamma]_] = \(3\/\(8  \[Gamma]\^3\)\) \((\((3 - \
\[Gamma]\^2)\) Log[\(1 + \[Gamma]\)\/\(1 - \[Gamma]\)] - 
              6  \[Gamma])\);\)\)}], "Input"],

Cell["Plot them", "Text"],

Cell[BoxData[
    \(\(Plot[{lift[\[Gamma]], drag[\[Gamma]], 
            moment[\[Gamma]]}, {\[Gamma], \(-1\), 1}, 
          PlotRange \[Rule] {\(-4\), 4}, 
          AxesLabel \[Rule] {"\<\[Gamma]\>", "\<f\>"}, 
          PlotStyle \[Rule] {Text["\<drag\>", {0.2, 1.3}, {\(-1\), \(-1\)}], 
              Text["\<lift\>", {0.4, 0.6}, {\(-1\), \(-1\)}], 
              Text["\<moment\>", {0.6, 
                  0.2}, {\(-1\), \(-1\)}]}] \
// \[IndentingNewLine]Figure["\<lubricate1\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Flow reversal", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(L = 2;\)\), "\[IndentingNewLine]", 
    \(\(d = 0.1;\)\), "\[IndentingNewLine]", 
    \(\(\[Gamma] = 0.6;\)\), "\[IndentingNewLine]", 
    \(\(U = 1;\)\)}], "Input"],

Cell["Height", "Text"],

Cell[BoxData[
    \(\(h[x_] = d\ \((1 - \[Gamma]\ \(2  x\)\/L)\);\)\)], "Input"],

Cell["Effective gap width", "Text"],

Cell[BoxData[
    \(d\_0 = \((1 - \[Gamma]\^2)\) d\)], "Input"],

Cell["Max height", "Text"],

Cell[BoxData[
    \(\(h\_0 = d \((1 + Abs[\[Gamma]])\);\)\)], "Input"],

Cell["Stream function", "Text"],

Cell[BoxData[
    \(\(\[Psi][x_, 
          y_] = \(1\/h[x]\^2\) \(\((h[x] - y)\)\^2\) 
            y + \(d\_0\/\(2  h[x]\^3\)\) \(y\^2\) \((3  h[x] - 
                2  y)\);\)\)], "Input"],

Cell[BoxData[
    \(\(fig4a = 
        ContourPlot[
          If[0 < y < h[x], \[Psi][x, y], 0], {x, \(-\(L\/2\)\), L\/2}, {y, 0, 
            h\_0}, PlotPoints \[Rule] 200, Contours \[Rule] 15, 
          ContourShading \[Rule] False, Frame \[Rule] False];\)\)], "Input"],

Cell[BoxData[
    \(\(fig4b = 
        Graphics[{Thickness[0.01], Line[{{\(-\(L\/2\)\), 0}, {L\/2, 0}}], 
            Thickness[0.004], Dashing[{0.01, 0.03}], 
            Line[{{\(-\(L\/2\)\), d\_0}, {L\/2, d\_0}}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig4a, 
          fig4b] // \[IndentingNewLine]Figure["\<lubricate4\>"];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Journal bearing", "Title"],

Cell[CellGroupData[{

Cell["Theory", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\($Assumptions = \(-1\) < \[Gamma] < 1 && d > 0 && \[Eta] > 0 && 
          U > 0 && \[Phi] > 0 && a > 0;\)\)], "Input"],

Cell["Shape of bearing", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(h = d \((1 - \[Gamma]\ Cos[\[Phi]])\);\)\)\)], "Input"],

Cell["Mean values ", "Text"],

Cell[BoxData[
    \(hm2 = \(1\/\(2  \[Pi]\)\) \(\[Integral]\_0\%\(2  \[Pi]\)h\^\(-2\)\ \(\(\
\[DifferentialD]\[Phi]\)\(\ \)\)\)\)], "Input"],

Cell[BoxData[
    \(hm3 = \(1\/\(2  \[Pi]\)\) \(\[Integral]\_0\%\(2  \[Pi]\)h\^\(-3\)\ \
\[DifferentialD]\[Phi]\)\  // Simplify\)], "Input"],

Cell["Effective gap width", "Text"],

Cell[BoxData[
    \(d\_0 = hm2\/hm3\)], "Input"],

Cell["Pressure derivative", "Text"],

Cell[BoxData[
    \(pd = 6  \[Eta]\ U\ \(h - d\_0\)\/h\^3 // Simplify\)], "Input"],

Cell["Pressure itself", "Text"],

Cell[BoxData[
    \(p = \[Integral]\_0\%\[Phi] pd\ a \[DifferentialD]\[Phi] // 
        Simplify\)], "Input"],

Cell["Check integral", "Text"],

Cell[BoxData[
    \(\(1\/a\) \[PartialD]\_\[Phi] p \[Equal] pd // Simplify\)], "Input"],

Cell["Calculate lift", "Text"],

Cell[BoxData[
    \(lift = \(-\(A\/\(2  \[Pi]\)\)\) \(\[Integral]\_0\%\(2  \[Pi]\)p\ Sin[\
\[Phi]]\ \ \[DifferentialD]\[Phi]\) // Simplify\)], "Input"],

Cell["Shear stress", "Text"],

Cell[BoxData[
    \(\[Sigma] = \(-\[Eta]\)\ U\ \(4\ h - 3  d\_0\)\/h\^2 // 
        Simplify\)], "Input"],

Cell["Moment on shaft", "Text"],

Cell[BoxData[
    \(moment = \(A\/\(2  \[Pi]\)\) \(\[Integral]\_0\%\(2  \[Pi]\)\ 
            a\ \[Sigma]\ \[DifferentialD]\[Phi]\) // Simplify\)], "Input"],

Cell["Power", "Text"],

Cell[BoxData[
    \(\(power = \(-\[CapitalOmega]\)\ moment;\)\)], "Input"],

Cell["Power to lift ratio", "Text"],

Cell[BoxData[
    \(power\/lift\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Shape factors", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\(lift = \(\(3\)  \(\[Gamma]\)\(\ \)\)\/\(\(\ \)\(\[Pi] \@\( 1 - \
\[Gamma]\^2\)\ \((2 + \[Gamma]\^2)\)\)\);\)\)], "Input"],

Cell[BoxData[
    \(\(power = \(\(2\)\(\ \ \)\((1 + 2\ \[Gamma]\^2)\)\(\ \)\)\/\(\@\(1 - \
\[Gamma]\^2\)\ \((2 + \[Gamma]\^2)\)\);\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[{lift, power}, {\[Gamma], \(-1\), 1}, 
          PlotRange \[Rule] {\(-4\), 4}, 
          AxesLabel \[Rule] {"\<\[Gamma]\>", "\<f\>"}, 
          PlotStyle \[Rule] {Text["\<lift\>", {0.7, 0.6}, {\(-1\), \(-1\)}], 
              Text["\<power\>", {0.4, 
                  1.8}, {\(-1\), \(-1\)}]}] \
// \[IndentingNewLine]Figure["\<lubricate2\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Flow reversal in polar coordinates", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(a = 1;\)\), "\n", 
    \(\(d = 0.4;\)\), "\n", 
    \(\(\[Gamma] = 0.6;\)\), "\n", 
    \(\(U = 1;\)\)}], "Input"],

Cell["Shape of gap", "Text"],

Cell[BoxData[
    \(\(h[x_] = d\ \((1 - \[Gamma]\ Cos[x\/a])\);\)\)], "Input"],

Cell["Discharge rate", "Text"],

Cell[BoxData[
    \(\(Q = U\ d\ \(1 - \[Gamma]\^2\)\/\(2 + \[Gamma]\^2\);\)\)], "Input"],

Cell["Stream function", "Text"],

Cell[BoxData[
    \(\(\[Psi][x_, y_] = 
        If[0 \[LessEqual] \ y \[LessEqual] \ 
            h[x], \(U\/h[x]\^2\) \(\((h[x] - y)\)\^2\) 
              y + \(Q\/h[x]\^3\) \(y\^2\) \((3  h[x] - 2  y)\), 
          0];\)\)], "Input"],

Cell["Gap parameters", "Text"],

Cell[BoxData[
    \(\(b = a + d;\)\)], "Input"],

Cell[BoxData[
    \(\(c = \[Gamma]\ d;\)\)], "Input"],

Cell["Effective gap width", "Text"],

Cell[BoxData[
    \(\(d\_0 = 
        d\ \(2 \((1 - \[Gamma]\^2)\)\)\/\(2 + \[Gamma]\^2\);\)\)], "Input"],

Cell[BoxData[
    \(\(\[Epsilon] = 0.02;\)\)], "Input"],

Cell["\<\
Stream function in Cartesian coordinates along the linearized gap\
\>", "Text"],

Cell[BoxData[
    \(\(\[Psi][x_, y_] = 
        U\ If[0 \[LessEqual] \ y \[LessEqual] \ 
              h[x], \(1\/h[x]\^2\) \(\((h[x] - y)\)\^2\) 
                y + \(d\_0\/\(2  h[x]\^3\)\) \(y\^2\) \((3  h[x] - 2  y)\), 
            0];\)\)], "Input"],

Cell["\<\
Stream function in true Cartesian coordinates for the circular gap\
\>", "Text"],

Cell[BoxData[
    \(\(f[x_, y_] = \[Psi][
          a\ ArcTan[x, y], \@\(x\^2 + y\^2\) - a];\)\)], "Input"],

Cell[BoxData[
    \(\(ContourPlot[
          f[x, y], {x, \(-\((b + c + \[Epsilon])\)\), 
            b - c + \[Epsilon]}, {y, \(-b\) - \[Epsilon], b + \[Epsilon]}, 
          PlotPoints \[Rule] 300, Contours \[Rule] 10, 
          ContourShading \[Rule] False, Frame \[Rule] False, 
          AspectRatio \[Rule] 
            1] // \[IndentingNewLine]Figure["\<lubricate5\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Title"],

Cell[CellGroupData[{

Cell["Integrals", "Section",
  FontSize->16],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell[BoxData[
    \(\($Assumptions = \(-1\) < \[Gamma] < 1 && \[Psi] > 0;\)\)], "Input"],

Cell[BoxData[
    \(\(f[\[Phi]_] = 1 - \[Gamma]\ Cos[\[Phi]];\)\)], "Input"],

Cell[BoxData[
    \(I1 = \[Integral]\_0\%\(2  \[Pi]\)\(1\/f[\[Phi]]\) \
\[DifferentialD]\[Phi]\/\(2  \[Pi]\)\)], "Input"],

Cell[BoxData[
    \(I2 = \[Integral]\_0\%\(2  \[Pi]\)\(1\/f[\[Phi]]\^2\) \[DifferentialD]\
\[Phi]\/\(2  \[Pi]\)\)], "Input"],

Cell[BoxData[
    \(I3 = \[Integral]\_0\%\(2  \[Pi]\)\(1\/f[\[Phi]]\^3\) \[DifferentialD]\
\[Phi]\/\(2  \[Pi]\) // Simplify\)], "Input"],

Cell[BoxData[
    \(I2\/I3 // Simplify\)], "Input"],

Cell[BoxData[
    \(g[\[Psi]_] = \[Integral]\_0\%\[Psi]\((1\/f[\[Phi]]\^2 - \(\(1 - \
\[Gamma]\^2\)\/\(2 + \[Gamma]\^2\)\) 
                2\/f[\[Phi]]\^3)\) \[DifferentialD]\[Phi]\)], "Input"],

Cell[BoxData[
    \(\[Integral]\_0\%\(2  \[Pi]\)g[\[Phi]]\ Cos[\[Phi]] \[DifferentialD]\
\[Phi]\)], "Input"],

Cell[BoxData[
    \(gL[\[Gamma]_] = \(-\(1\/\[Pi]\)\) \(\[Integral]\_0\%\(2  \
\[Pi]\)g[\[Phi]]\ Sin[\[Phi]] \[DifferentialD]\[Phi]\)\)], "Input"],

Cell[BoxData[
    \(gM[\[Gamma]_] = \(1\/\[Pi]\) \(\[Integral]\_0\%\(2  \[Pi]\)\((2\/f[\
\[Phi]] - 3 \(\( 1 - \ \[Gamma]\^2\)\/\(2 + \[Gamma]\^2\)\) 
                    1\/f[\[Phi]]\^2)\) \[DifferentialD]\[Phi]\) // 
        Simplify\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
AutoGeneratedPackage->None,
WindowSize->{804, 819},
WindowMargins->{{17, Automatic}, {Automatic, 28}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 32, 0, 95, "Title"],
Cell[1811, 55, 72, 2, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[1920, 62, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[1970, 66, 37, 0, 73, "Section"],
Cell[2010, 68, 46, 1, 30, "Input"],
Cell[2059, 71, 26, 0, 33, "Text"],
Cell[2088, 73, 423, 7, 150, "Input"],
Cell[2514, 82, 31, 0, 33, "Text"],
Cell[2548, 84, 73, 1, 44, "Input"],
Cell[2624, 87, 40, 0, 33, "Text"],
Cell[2667, 89, 74, 1, 48, "Input"],
Cell[2744, 92, 43, 0, 33, "Text"],
Cell[2790, 94, 54, 1, 30, "Input"],
Cell[2847, 97, 28, 0, 33, "Text"],
Cell[2878, 99, 46, 1, 30, "Input"],
Cell[2927, 102, 33, 0, 33, "Text"],
Cell[2963, 104, 93, 1, 51, "Input"],
Cell[3059, 107, 31, 0, 33, "Text"],
Cell[3093, 109, 76, 1, 42, "Input"],
Cell[3172, 112, 34, 0, 33, "Text"],
Cell[3209, 114, 48, 1, 42, "Input"],
Cell[3260, 117, 43, 0, 33, "Text"],
Cell[3306, 119, 114, 2, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3457, 126, 44, 1, 70, "Section"],
Cell[3504, 129, 51, 1, 30, "Input"],
Cell[3558, 132, 609, 13, 208, "Input"],
Cell[4170, 147, 79, 2, 30, "Input"],
Cell[4252, 151, 76, 2, 30, "Input"],
Cell[4331, 155, 31, 0, 33, "Text"],
Cell[4365, 157, 83, 2, 43, "Input"],
Cell[4451, 161, 40, 0, 33, "Text"],
Cell[4494, 163, 95, 2, 51, "Input"],
Cell[4592, 167, 38, 0, 33, "Text"],
Cell[4633, 169, 72, 1, 43, "Input"],
Cell[4708, 172, 42, 0, 33, "Text"],
Cell[4753, 174, 70, 1, 42, "Input"],
Cell[4826, 177, 48, 1, 30, "Input"],
Cell[4877, 180, 31, 0, 33, "Text"],
Cell[4911, 182, 66, 1, 43, "Input"],
Cell[4980, 185, 20, 0, 33, "Text"],
Cell[5003, 187, 100, 2, 43, "Input"],
Cell[5106, 191, 36, 0, 33, "Text"],
Cell[5145, 193, 88, 2, 43, "Input"],
Cell[5236, 197, 25, 0, 33, "Text"],
Cell[5264, 199, 66, 2, 30, "Input"],
Cell[5333, 203, 25, 0, 33, "Text"],
Cell[5361, 205, 93, 2, 43, "Input"],
Cell[5457, 209, 54, 2, 30, "Input"],
Cell[5514, 213, 64, 2, 43, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5627, 221, 50, 0, 95, "Title"],
Cell[5680, 223, 46, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[5751, 228, 25, 0, 73, "Section"],
Cell[5779, 230, 26, 0, 33, "Text"],
Cell[5808, 232, 107, 2, 63, "Input"],
Cell[5918, 236, 27, 0, 33, "Text"],
Cell[5948, 238, 298, 6, 80, "Input"],
Cell[6249, 246, 31, 0, 33, "Text"],
Cell[6283, 248, 191, 4, 44, "Input"],
Cell[6477, 254, 61, 0, 33, "Text"],
Cell[6541, 256, 86, 1, 30, "Input"],
Cell[6630, 259, 85, 1, 30, "Input"],
Cell[6718, 262, 29, 0, 33, "Text"],
Cell[6750, 264, 102, 3, 70, "Input"],
Cell[6855, 269, 79, 1, 33, "Input"],
Cell[6937, 272, 25, 0, 33, "Text"],
Cell[6965, 274, 78, 1, 31, "Input"],
Cell[7046, 277, 78, 1, 31, "Input"],
Cell[7127, 280, 35, 0, 33, "Text"],
Cell[7165, 282, 46, 1, 42, "Input"],
Cell[7214, 285, 28, 0, 33, "Text"],
Cell[7245, 287, 261, 5, 50, "Input"],
Cell[7509, 294, 207, 4, 50, "Input"],
Cell[7719, 300, 143, 3, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7911, 309, 26, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[7962, 313, 44, 1, 70, "Section"],
Cell[8009, 316, 67, 2, 30, "Input"],
Cell[8079, 320, 33, 0, 33, "Text"],
Cell[8115, 322, 149, 3, 50, "Input"],
Cell[8267, 327, 31, 0, 33, "Text"],
Cell[8301, 329, 90, 2, 44, "Input"],
Cell[8394, 333, 29, 0, 33, "Text"],
Cell[8426, 335, 57, 1, 30, "Input"],
Cell[8486, 338, 35, 0, 33, "Text"],
Cell[8524, 340, 68, 1, 31, "Input"],
Cell[8595, 343, 24, 0, 33, "Text"],
Cell[8622, 345, 141, 2, 43, "Input"],
Cell[8766, 349, 20, 0, 33, "Text"],
Cell[8789, 351, 83, 1, 30, "Input"],
Cell[8875, 354, 134, 3, 49, "Input"],
Cell[9012, 359, 42, 0, 33, "Text"],
Cell[9057, 361, 107, 2, 44, "Input"],
Cell[9167, 365, 38, 0, 33, "Text"],
Cell[9208, 367, 146, 3, 49, "Input"],
Cell[9357, 372, 177, 3, 44, "Input"],
Cell[9537, 377, 138, 3, 49, "Input"],
Cell[9678, 382, 208, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9923, 390, 50, 1, 70, "Section"],
Cell[9976, 393, 46, 1, 30, "Input"],
Cell[10025, 396, 31, 0, 33, "Text"],
Cell[10059, 398, 568, 9, 137, "Input"],
Cell[10630, 409, 25, 0, 33, "Text"],
Cell[10658, 411, 503, 9, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11198, 425, 32, 0, 73, "Section"],
Cell[11233, 427, 51, 1, 30, "Input"],
Cell[11287, 430, 26, 0, 33, "Text"],
Cell[11316, 432, 188, 4, 90, "Input"],
Cell[11507, 438, 22, 0, 33, "Text"],
Cell[11532, 440, 80, 1, 42, "Input"],
Cell[11615, 443, 35, 0, 33, "Text"],
Cell[11653, 445, 63, 1, 31, "Input"],
Cell[11719, 448, 26, 0, 33, "Text"],
Cell[11748, 450, 70, 1, 30, "Input"],
Cell[11821, 453, 31, 0, 33, "Text"],
Cell[11855, 455, 191, 4, 44, "Input"],
Cell[12049, 461, 272, 5, 64, "Input"],
Cell[12324, 468, 233, 4, 76, "Input"],
Cell[12560, 474, 114, 2, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12723, 482, 32, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[12780, 486, 25, 0, 73, "Section"],
Cell[12808, 488, 46, 1, 30, "Input"],
Cell[12857, 491, 140, 2, 30, "Input"],
Cell[13000, 495, 32, 0, 33, "Text"],
Cell[13035, 497, 85, 1, 30, "Input"],
Cell[13123, 500, 28, 0, 33, "Text"],
Cell[13154, 502, 140, 2, 43, "Input"],
Cell[13297, 506, 140, 2, 43, "Input"],
Cell[13440, 510, 35, 0, 33, "Text"],
Cell[13478, 512, 48, 1, 42, "Input"],
Cell[13529, 515, 35, 0, 33, "Text"],
Cell[13567, 517, 82, 1, 42, "Input"],
Cell[13652, 520, 31, 0, 33, "Text"],
Cell[13686, 522, 109, 2, 42, "Input"],
Cell[13798, 526, 30, 0, 33, "Text"],
Cell[13831, 528, 87, 1, 42, "Input"],
Cell[13921, 531, 30, 0, 33, "Text"],
Cell[13954, 533, 151, 2, 43, "Input"],
Cell[14108, 537, 28, 0, 33, "Text"],
Cell[14139, 539, 105, 2, 42, "Input"],
Cell[14247, 543, 31, 0, 33, "Text"],
Cell[14281, 545, 156, 2, 43, "Input"],
Cell[14440, 549, 21, 0, 33, "Text"],
Cell[14464, 551, 74, 1, 30, "Input"],
Cell[14541, 554, 35, 0, 33, "Text"],
Cell[14579, 556, 44, 1, 40, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14660, 562, 32, 0, 73, "Section"],
Cell[14695, 564, 46, 1, 30, "Input"],
Cell[14744, 567, 143, 2, 49, "Input"],
Cell[14890, 571, 145, 2, 52, "Input"],
Cell[15038, 575, 389, 7, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15464, 587, 53, 0, 73, "Section"],
Cell[15520, 589, 46, 1, 30, "Input"],
Cell[15569, 592, 137, 4, 90, "Input"],
Cell[15709, 598, 28, 0, 33, "Text"],
Cell[15740, 600, 78, 1, 40, "Input"],
Cell[15821, 603, 30, 0, 33, "Text"],
Cell[15854, 605, 88, 1, 47, "Input"],
Cell[15945, 608, 31, 0, 33, "Text"],
Cell[15979, 610, 235, 5, 44, "Input"],
Cell[16217, 617, 30, 0, 33, "Text"],
Cell[16250, 619, 47, 1, 30, "Input"],
Cell[16300, 622, 53, 1, 30, "Input"],
Cell[16356, 625, 35, 0, 33, "Text"],
Cell[16394, 627, 105, 2, 47, "Input"],
Cell[16502, 631, 55, 1, 30, "Input"],
Cell[16560, 634, 89, 2, 33, "Text"],
Cell[16652, 638, 254, 5, 44, "Input"],
Cell[16909, 645, 90, 2, 33, "Text"],
Cell[17002, 649, 107, 2, 34, "Input"],
Cell[17112, 653, 426, 8, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17587, 667, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[17637, 671, 44, 1, 68, "Section"],
Cell[17684, 674, 51, 1, 30, "Input"],
Cell[17738, 677, 88, 1, 30, "Input"],
Cell[17829, 680, 76, 1, 30, "Input"],
Cell[17908, 683, 121, 2, 44, "Input"],
Cell[18032, 687, 124, 2, 44, "Input"],
Cell[18159, 691, 136, 2, 44, "Input"],
Cell[18298, 695, 51, 1, 42, "Input"],
Cell[18352, 698, 194, 3, 47, "Input"],
Cell[18549, 703, 108, 2, 42, "Input"],
Cell[18660, 707, 146, 2, 42, "Input"],
Cell[18809, 711, 247, 4, 47, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

